"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeVersionUpgradeInitializer = exports.NODE_UPGRADE_INITIALIZER = void 0;
const node_util_1 = require("node:util");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const metadata_1 = require("@jfrog-pipelines/metadata");
const NodeDao_1 = require("./modules/node/NodeDao");
exports.NODE_UPGRADE_INITIALIZER = 'NodeVersionUpgradeInitializer';
class NodeVersionUpgradeInitializer {
    async init(options) {
        const applicationContext = options.applicationContext;
        this.properties = options.properties;
        this.logger = options.logger;
        const storeValue = applicationContext.get(exports.NODE_UPGRADE_INITIALIZER) ?? {};
        if (!storeValue.initialized) {
            this.logger.info(`Running ${exports.NODE_UPGRADE_INITIALIZER} to upgrade node buildplane version to  ${this.properties
                .buildPlaneVersion}`);
            const nodeDao = new NodeDao_1.NodeDao();
            try {
                const updateQuery = `UPDATE nodes SET "statusCode"=${metadata_1.FAILED} WHERE "currentBuildPlaneVersion" != "intendedBuildPlaneVersion" AND "statusCode" not in (${metadata_1.PROCESSING}) AND "isOnDemand" = true`;
                const updatedNodes = await nodeDao.query(updateQuery, { type: data_access_layer_1.QueryTypes.UPDATE, model: data_access_layer_1.Node });
                this.logger.info(`Nodes soft deleted due to version mismatch ${(0, node_util_1.inspect)(updatedNodes)}`);
            }
            catch (error) {
                this.logger.error(`Failed to initialize node upgrade initalizer due to err ${(0, node_util_1.inspect)(error)}`);
            }
        }
    }
}
exports.NodeVersionUpgradeInitializer = NodeVersionUpgradeInitializer;
//# sourceMappingURL=NodeVersionUpgradeInitializer.js.map