"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiStepDataAdapter = void 0;
const configuration_1 = require("@jfrog-pipelines/configuration");
const utility_1 = require("@jfrog-pipelines/utility");
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const metadata_1 = require("@jfrog-pipelines/metadata");
class ApiStepDataAdapter {
    constructor() {
        this.properties = configuration_1.ConfigFactory.config;
        this.client = new internal_clients_1.PipelinesClient(12, this.properties.apiToken);
        this.startTimeInMs = Date.now() * 1000;
        const processStartTime = process.hrtime();
        this.processStartTimeInMicroSec = processStartTime[0] * 1e6 + processStartTime[1] / 1e3;
    }
    async getBuildPlaneMessages(queryString) {
        return this.client.getBuildPlaneMessages(queryString);
    }
    async putBuildPlaneMessageById(messageId, message) {
        return this.client.putBuildPlaneMessageById(messageId, message);
    }
    getStepById(stepId) {
        return this.client.getStepById(stepId);
    }
    async getStepsQueuedToTheNode(affinityGroup, runId) {
        const statusCodes = [metadata_1.WAITING, metadata_1.PROCESSING, metadata_1.QUEUED, metadata_1.CANCELLING, metadata_1.TIMINGOUT].join(',');
        const query = `affinityGroups=${affinityGroup}&runIds=${runId}&statusCodes=${statusCodes}`;
        return this.client.getSteps(query);
    }
    async timeOutSteps(steps) {
        const update = {
            statusCode: metadata_1.TIMEOUT
        };
        const batch = 10;
        await (0, utility_1.eachLimit)(steps, batch, async (step) => {
            await this.client.updateStep(step.id, update);
        });
    }
    async postMessageToStepConsole(groupName, cmdName, message, stepId, pipelineId) {
        const consoleGroupId = (0, utility_1.uuidv5)('openGrp', utility_1.uuidv5.URL);
        const consoleCmdId = (0, utility_1.uuidv5)('openCmd', utility_1.uuidv5.URL);
        const consoleMessageId = (0, utility_1.uuidv5)('publishMsg', utility_1.uuidv5.URL);
        await this.postConsole(groupName, stepId, pipelineId, consoleGroupId, 'root', 'grp', true);
        await this.postConsole(cmdName, stepId, pipelineId, consoleCmdId, consoleGroupId, 'cmd', true);
        await this.postConsole(message, stepId, pipelineId, consoleMessageId, consoleCmdId, 'msg', true);
        await this.postConsole(cmdName, stepId, pipelineId, consoleCmdId, consoleGroupId, 'cmd', false, true);
        await this.postConsole(groupName, stepId, pipelineId, consoleGroupId, 'root', 'grp', true, true);
    }
    async postConsole(message, stepId, pipelineId, consoleId, parentConsoleId, type, isShown, isSuccess) {
        const stepConsole = {
            stepId: stepId,
            consoleId: consoleId,
            parentConsoleId: parentConsoleId,
            type: type,
            message: message,
            timestamp: this.getTimeStamp(),
            timestampEndedAt: this.getTimeStamp(),
            isShown: isShown,
            isSuccess: isSuccess
        };
        const body = {
            stepId: stepId,
            pipelineId: pipelineId,
            stepConsoles: [stepConsole]
        };
        await this.client.postStepConsoles(body);
    }
    getTimeStamp() {
        const currentProcessTime = process.hrtime();
        return Math.round(this.startTimeInMs + (currentProcessTime[0] * 1e6 + currentProcessTime[1] / 1e3) - this.processStartTimeInMicroSec);
    }
}
exports.ApiStepDataAdapter = ApiStepDataAdapter;
//# sourceMappingURL=ApiStepDataAdapter.js.map