"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const metadata_1 = require("@jfrog-pipelines/metadata");
const StepRepository_1 = require("../StepRepository");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'testtoken' } }
    };
});
describe('StepRepository', () => {
    describe('resetBuildPlaneByNodeId', () => {
        const stepRepository = new StepRepository_1.StepRepository();
        it('should reset the build plane for the given node ID', async () => {
            const nodeId = 123;
            const queryString = `nodeIds=${nodeId}&statusCodes=${metadata_1.READY},${metadata_1.QUEUED}`;
            const data = [
                {
                    id: 1,
                    nodeId: 123,
                    projectId: 1,
                    nodePoolId: 1,
                    statusCode: metadata_1.READY
                },
                {
                    id: 2,
                    nodeId: 1234,
                    projectId: 1,
                    nodePoolId: 1,
                    statusCode: metadata_1.QUEUED
                }
            ];
            jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getBuildPlaneMessages').mockResolvedValueOnce(data);
            jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'putBuildPlaneMessageById').mockResolvedValueOnce({
                id: 1,
                projectId: 1,
                statusCode: metadata_1.READY
            });
            await stepRepository.resetBuildPlaneByNodeId(nodeId);
            expect(internal_clients_1.PipelinesClient.prototype.getBuildPlaneMessages).toHaveBeenCalledWith(queryString);
            expect(internal_clients_1.PipelinesClient.prototype.putBuildPlaneMessageById).toHaveBeenCalledWith(1, {
                resetBuildPlaneMessage: true,
                nodeId: nodeId
            });
        });
    });
});
//# sourceMappingURL=StepRepository.test.js.map