"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ApiUserDataAdapter_1 = require("../ApiUserDataAdapter");
const UserRepository_1 = require("./../UserRepository");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'testtoken' } }
    };
});
describe('UserRepository', () => {
    const userRepository = new UserRepository_1.UserRepository();
    describe('getProjectById', () => {
        it('should return the project attributes', async () => {
            const id = 123;
            const projectAttributes = { id: 123, name: 'Project 1' };
            jest.spyOn(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype, 'getProjectById').mockResolvedValueOnce(projectAttributes);
            const result = await userRepository.getProjectById(id);
            expect(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype.getProjectById).toHaveBeenCalledWith(id);
            expect(result).toBe(projectAttributes);
        });
    });
    describe('getProjectIntegrationById', () => {
        it('should return the project integration attributes', async () => {
            const id = 456;
            const projectIntegrationAttributes = {
                id: 456,
                integrationName: 'Integration 1'
            };
            jest
                .spyOn(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype, 'getProjectIntegrationById')
                .mockResolvedValueOnce(projectIntegrationAttributes);
            const result = await userRepository.getProjectIntegrationById(id);
            expect(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype.getProjectIntegrationById).toHaveBeenCalledWith(id);
            expect(result).toBe(projectIntegrationAttributes);
        });
    });
    describe('getUnifiedUiAndWwwUrl', () => {
        it('should return the unified UI and WWW URL', async () => {
            const unifiedUiAndWwwUrl = { unifiedUiUrl: 'https://example.com/ui', wwwUrl: 'https://example.com' };
            jest.spyOn(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype, 'getUnifiedUiAndWwwUrl').mockResolvedValueOnce(unifiedUiAndWwwUrl);
            const result = await userRepository.getUnifiedUiAndWwwUrl();
            expect(ApiUserDataAdapter_1.ApiUserDataAdapter.prototype.getUnifiedUiAndWwwUrl).toHaveBeenCalledTimes(1);
            expect(result).toBe(unifiedUiAndWwwUrl);
        });
    });
});
//# sourceMappingURL=UserRepository.test.js.map