"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const statusCodes = require('./marshaller/statusCodes.js');
global.request = require('request');
global.util = require('node:util');
const metadata_1 = require("@jfrog-pipelines/metadata");
const microservice_1 = require("@jfrog-pipelines/microservice");
const utility_1 = require("@jfrog-pipelines/utility");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const logger_1 = require("@jfrog-pipelines/logger");
const configuration_1 = require("@jfrog-pipelines/configuration");
const NodePoolWorker_1 = require("./NodePoolWorker");
const constants_1 = require("./marshaller/constants");
const lodash_1 = __importDefault(require("lodash"));
const v1_1 = require("./routes/v1");
const NodeVersionUpgradeInitializer_1 = require("./NodeVersionUpgradeInitializer");
const types_1 = require("@jfrog-pipelines/types");
global.request = require('request');
global.util = require('node:util');
global._ = require('underscore');
global.async = require('async');
const logLevel = 'info';
const QUEUE_NAME = 'core.nodePoolService';
const serviceEnum = 12;
const serviceDetails = utility_1.ServiceMeta[serviceEnum];
const options = {
    enum: serviceEnum,
    initializers: [new microservice_1.AmqpClientInitializer(), new NodeVersionUpgradeInitializer_1.NodeVersionUpgradeInitializer()],
    healthChecks: [],
    logLevel: logLevel,
    models: [data_access_layer_1.BuildPlaneMessage, data_access_layer_1.Lock, data_access_layer_1.Node, data_access_layer_1.NodePool, data_access_layer_1.SystemConfig, data_access_layer_1.NodeStats, data_access_layer_1.BuildPlaneImages, data_access_layer_1.NodeConsole],
    productHome: process.env.APP_CONFIG_PATH,
    validator: new microservice_1.DefaultApplicationValidator([], []),
    isAccessEnabled: true,
    apiRoutes: {
        serverPrefix: 'api/v1',
        routes: v1_1.nodepoolRoutesV1,
        schemas: [types_1.NodeStatsResponseSchema, types_1.NodeConsoleResponseSchema],
        documentation: {
            title: 'nodepool-service',
            description: 'NodePool Microservice open apis 3',
            version: '1.0.0'
        }
    }
};
async function startApp() {
    const app = new microservice_1.Application(options, microservice_1.applicationContext);
    global.logger = logger_1.LoggerFactory.getLogger('Marshaller');
    const defaultK8sMemory = 5000;
    const defaultK8sCPU = 1.5;
    global.config = {
        apiUrl: configuration_1.ConfigFactory.config.apiUrl,
        apiToken: configuration_1.ConfigFactory.config.apiToken,
        apiExternalUrl: configuration_1.ConfigFactory.config.externalApiUrl,
        instanceType: configuration_1.ConfigFactory.config.getCustom('runtime.instanceType') ?? 't3a.medium',
        runMode: configuration_1.ConfigFactory.config.getCustom('core.runMode'),
        nodePollerIntervalMS: configuration_1.ConfigFactory.config.nodePollerIntervalMS,
        customCertsEnabled: configuration_1.ConfigFactory.config.customCertsEnabled,
        noVerifySsl: configuration_1.ConfigFactory.config.getCustom('core.noVerifySsl'),
        isSaas: configuration_1.ConfigFactory.config.isSaaS,
        saasCustomerName: configuration_1.ConfigFactory.config.getCustom('runtime.saasCustomerName'),
        saasEnvironment: configuration_1.ConfigFactory.config.getCustom('runtime.saasEnvironment'),
        registryUrl: configuration_1.ConfigFactory.config.getCustom('core.registryUrl'),
        imageRegistrySecret: configuration_1.ConfigFactory.config.getCustom('core.imageRegistrySecret'),
        runOnePodInOneNode: configuration_1.ConfigFactory.config.getCustom('runtime.runOnePodInOneNode'),
        defaultK8sMemory: configuration_1.ConfigFactory.config.getCustom('runtime.defaultK8sMemory') ?? defaultK8sMemory,
        defaultK8sCPU: configuration_1.ConfigFactory.config.getCustom('runtime.defaultK8sCPU') ?? defaultK8sCPU
    };
    global.statusCodes = statusCodes;
    const systemCodes = (0, metadata_1.getSystemCodes)();
    global.systemCodes = systemCodes;
    global.systemCodesByName = (0, metadata_1.getSystemCodesByName)();
    global.systemCodesByCode = (0, metadata_1.getSystemCodesByCode)();
    global.systemCodesByGroup = lodash_1.default.groupBy(systemCodes, 'group');
    lodash_1.default.each(global.systemCodesByGroup, (groupCodes, group) => {
        global.systemCodesByGroup[group] = lodash_1.default.keyBy(groupCodes, 'name');
    });
    global.logger = logger_1.LoggerFactory.getLogger('NodePoolService');
    global.msName = 'nodePoolService';
    global.jobConsoleBufferTimeInterval = 10;
    global.request = global.request.defaults({
        headers: {
            Connection: 'keep-alive',
            'Keep-Alive': `timeout=${constants_1.KEEP_ALIVE.TIMEOUT_SEC}, max=${constants_1.KEEP_ALIVE.MAX_CONNECTIONS}`
        }
    });
    const poolWorker = new NodePoolWorker_1.NodePoolWorker(serviceDetails, microservice_1.applicationContext);
    await app.listen(QUEUE_NAME, poolWorker);
    global.customCertsData = microservice_1.applicationContext.get(microservice_1.CERTIFICATE_INITIALIZER);
}
startApp();
//# sourceMappingURL=app.js.map