'use strict';
var self = Adapter;
module.exports = self;
var uuid = require('node-uuid');
var ApiAdapter = require('./Adapter.js');
function Adapter(jFrogPipelinesSessionId, nodeId, projectId) {
    this.who = util.format('%s|_global|pipelines|NodeConsoleAdapter' +
        '|jFrogPipelinesSessionId:%s|nodeId:%s', msName, jFrogPipelinesSessionId, nodeId);
    this.nodeId = nodeId;
    this.projectId = projectId;
    this.startTimeInMicroSec = new Date().getTime() * 1000;
    var processStartTime = process.hrtime();
    this.processStartTimeInMicroSec =
        processStartTime[0] * 1e6 + processStartTime[1] / 1e3;
    this.apiAdapter = new ApiAdapter(jFrogPipelinesSessionId, global.config.apiToken);
    this.batchSize = 20;
    this.buffer = [];
    this.bufferTimeInterval = 3000;
    this.bufferTimer = null;
    this.pendingApiCalls = 0;
}
Adapter.prototype.openGrp = function (consoleGrpName) {
    var that = this;
    var who = that.who + '|_openGrp';
    that.consoleGrpName = consoleGrpName;
    that.consoleGrpId = uuid.v4();
    if (_.isEmpty(consoleGrpName))
        throw new ActErr(who, ActErr.ParamNotFound, 'Missing param :consoleGrpName');
    var consoleGrp = {
        nodeId: that.nodeId,
        projectId: that.projectId,
        consoleId: that.consoleGrpId,
        parentConsoleId: 'root',
        type: 'grp',
        message: that.consoleGrpName,
        timestamp: that._getTimestamp(),
        completed: false,
        isShown: true
    };
    that.buffer.push(consoleGrp);
    that._postToNodeConsole(true);
};
Adapter.prototype.closeGrp = function (isSuccess) {
    var that = this;
    if (!that.consoleGrpName)
        return;
    if (!_.isBoolean(isSuccess))
        isSuccess = true;
    that.closeCmd();
    var consoleGrp = {
        nodeId: that.nodeId,
        projectId: that.projectId,
        consoleId: that.consoleGrpId,
        parentConsoleId: 'root',
        type: 'grp',
        message: that.consoleGrpName,
        timestamp: that._getTimestamp(),
        timestampEndedAt: that._getTimestamp(),
        isSuccess: isSuccess,
        isShown: true
    };
    that.buffer.push(consoleGrp);
    that._postToNodeConsole(true);
    that.consoleGrpName = null;
    that.consoleGrpId = null;
};
Adapter.prototype.openCmd = function (consoleCmdName) {
    var that = this;
    var who = that.who + '|_openCmd';
    if (_.isEmpty(consoleCmdName))
        throw new ActErr(who, ActErr.ParamNotFound, 'Missing param :consoleCmdName');
    that.consoleCmdName = consoleCmdName;
    that.consoleCmdId = uuid.v4();
    var consoleGrp = {
        nodeId: that.nodeId,
        projectId: that.projectId,
        consoleId: that.consoleCmdId,
        parentConsoleId: that.consoleGrpId,
        type: 'cmd',
        message: that.consoleCmdName,
        timestamp: that._getTimestamp(),
        completed: false
    };
    that.buffer.push(consoleGrp);
    that._postToNodeConsole(true);
};
Adapter.prototype.closeCmd = function (isSuccess) {
    var that = this;
    if (!that.consoleCmdName)
        return;
    if (!_.isBoolean(isSuccess))
        isSuccess = true;
    var consoleGrp = {
        nodeId: that.nodeId,
        projectId: that.projectId,
        consoleId: that.consoleCmdId,
        parentConsoleId: that.consoleGrpId,
        type: 'cmd',
        message: that.consoleCmdName,
        timestamp: that._getTimestamp(),
        completed: isSuccess
    };
    that.buffer.push(consoleGrp);
    that._postToNodeConsole(true);
    that.consoleCmdName = null;
    that.consoleCmdId = null;
};
Adapter.prototype.publishMsg = function (message) {
    var that = this;
    var consoleGrp = {
        nodeId: that.nodeId,
        projectId: that.projectId,
        consoleId: uuid.v4(),
        parentConsoleId: that.consoleCmdId,
        type: 'msg',
        message: message + '\n',
        timestamp: that._getTimestamp()
    };
    that.buffer.push(consoleGrp);
    that._postToNodeConsole(false);
};
Adapter.prototype.getPendingApiCallCount = function () {
    var that = this;
    return that.pendingApiCalls;
};
Adapter.prototype._postToNodeConsole = function (forced) {
    var that = this;
    var who = that.who + '|_postToNodeConsole';
    if (that.buffer.length > that.batchSize || forced) {
        if (that.bufferTimer) {
            clearTimeout(that.bufferTimer);
            that.bufferTimer = null;
        }
        var consoles = that.buffer.splice(0, that.buffer.length);
        if (consoles.length === 0)
            return;
        var body = {
            nodeConsoleModels: consoles
        };
        that.pendingApiCalls++;
        that.apiAdapter.postToNodeConsoles(body, function (err) {
            that.pendingApiCalls--;
            if (err) {
                logger.error(who, 'postToNodeConsoles Failed', err);
                logger.error(who, util.inspect(body));
            }
            logger.trace(who, 'Succeeded');
        });
    }
    else if (!that.bufferTimer) {
        that.bufferTimer = setTimeout(function () {
            this._postToNodeConsole(true);
        }.bind(that), that.bufferTimeInterval);
    }
};
Adapter.prototype._getTimestamp = function () {
    var that = this;
    var currentProcessTime = process.hrtime();
    return Math.round(that.startTimeInMicroSec +
        (currentProcessTime[0] * 1e6 + currentProcessTime[1] / 1e3) -
        that.processStartTimeInMicroSec);
};
//# sourceMappingURL=NodeConsoleAdapter.js.map