'use strict';
var self = createNode;
module.exports = self;
var nodeActions = require('../nodeActions.js');
var nodeMetadataMap = require('../nodeMetadataMap.js');
function createNode(externalBag, callback) {
    var bag = {
        runtime: externalBag.runtime,
        buildPlaneMessageId: externalBag.buildPlaneMessageId,
        buildPlaneImage: externalBag.buildPlaneImage,
        providerName: externalBag.providerName,
        integrationValues: externalBag.integrationValues,
        node: externalBag.node,
        project: externalBag.project,
        params: {},
        apiUrl: config.apiExternalUrl,
        nodePool: externalBag.nodePool,
        consoleAdapter: externalBag.consoleAdapter,
        suAdapter: externalBag.suAdapter
    };
    bag.who = util.format('marshaller|_common|%s|jFrogPipelinesSessionId:%s|' +
        'node.id:%s', self.name, externalBag.jFrogPipelinesSessionId, bag.node.id);
    logger.debug(bag.who, 'Starting');
    async.series([
        _getUnifiedUiUrl.bind(null, bag),
        _prepData.bind(null, bag)
    ], function (err) {
        if (err)
            logger.warn(bag.who, 'Failed node.id:', bag.node.id);
        else
            logger.debug(bag.who, 'Successfully processed node.id:', bag.node.id);
        return callback(err, bag.params);
    });
}
function _getUnifiedUiUrl(bag, next) {
    const who = bag.who + '|' + _getUnifiedUiUrl.name;
    logger.debug(who, 'Inside');
    bag.suAdapter.getUnifiedUiAndWwwUrl(function (err, result) {
        if (err) {
            logger.error(who, 'Failed to get unified ui url with error: ' + util.inspect(err));
            return next(err);
        }
        bag.rtUiUrl = result.rtUiUrl;
        bag.wwwUrl = result.wwwUrl;
        return next();
    });
}
function _prepData(bag, next) {
    var who = self.name + '|' + _prepData.name;
    logger.trace(who, 'Inside');
    var providerMetadata = bag.nodePool.providerMetadataPropertyBag || {};
    var arch = bag.nodePool.architecture;
    var os = bag.nodePool.operatingSystem;
    var buildPlaneArtifactExtension = nodeMetadataMap.getBuildPlaneArtifactExtension(arch, os);
    bag.params = {
        action: nodeActions.CREATE,
        runtime: bag.runtime,
        buildPlaneMessageId: bag.buildPlaneMessageId,
        nodePool: bag.nodePool,
        startupScriptData: {
            nodeId: bag.node.id,
            projectId: bag.project.id,
            buildPlaneVersion: bag.node.intendedBuildPlaneVersion,
            apiExternalUrl: global.config.apiExternalUrl,
            wwwUrl: bag.wwwUrl,
            baseUrlUI: bag.rtUiUrl,
            runMode: global.config.runMode,
            architecture: bag.nodePool.architecture,
            operatingSystem: bag.nodePool.operatingSystem,
            buildPlaneArtifactDownloadUrl: util.format('%s/pipelines/webapp/buildPlane-%s-%s.%s', bag.rtUiUrl, arch, os, buildPlaneArtifactExtension),
            configureNode: false,
            installPrereqs: false,
            isSwapEnabled: false,
            token: bag.node.systemPropertyBag && bag.node.systemPropertyBag.token,
            nodePollerIntervalMS: global.config.nodePollerIntervalMS,
            noVerifySsl: global.config.noVerifySsl,
            customCertsEnabled: global.config.customCertsEnabled,
            customCertsData: JSON.stringify(global.config.customCertsData),
            rootUserInit: !bag.nodePool.initAsNonRoot
        },
        nodeId: bag.node.id,
        nodeStatus: bag.node.statusCode,
        nodeProviderMetadata: bag.node.providerMetadataPropertyBag,
        projectId: bag.project.id,
        projectName: bag.project.name,
        architecture: arch,
        operatingSystem: os,
        nodeName: bag.node.friendlyName,
        nodeSSHUser: bag.node.sshUser,
        nodeSSHPort: bag.node.sshPort,
        isDefaultIntegration: true,
        buildPlaneImage: bag.buildPlaneImage,
        region: bag.buildPlaneImage && bag.buildPlaneImage.region,
        imageId: bag.buildPlaneImage && bag.buildPlaneImage.imageId,
        imageMetadata: bag.buildPlaneImage &&
            bag.buildPlaneImage.metadataPropertyBag,
        providerName: bag.providerName,
        consoleAdapter: bag.consoleAdapter,
        nodePoolId: bag.nodePool.id,
        providerMetadata: providerMetadata,
        nodePoolName: bag.nodePool.name
    };
    if (bag.nodePool.diskSizeinGB)
        bag.params.diskSizeinGB = bag.nodePool.diskSizeinGB;
    if (_.has(bag.nodePool, 'initPropertyBag') &&
        _.has(bag.nodePool.initPropertyBag, 'insecureDockerRegistries'))
        bag.params.startupScriptData.insecureDockerRegistries =
            bag.nodePool.initPropertyBag.insecureDockerRegistries;
    bag.params = _.extend(bag.params, bag.integrationValues);
    return next();
}
//# sourceMappingURL=createNode.js.map