'use strict';
var Compute = require('@google-cloud/compute');
var _ = require('underscore');
var async = require('async');
var self = Adapter;
module.exports = self;
var { EXPONENTIAL_RETRY_OPTIONS } = require('../../../constants.js');
function wrapWithRetry(ctx, func) {
    const options = {
        ...EXPONENTIAL_RETRY_OPTIONS,
        errorFilter: function (err) {
            let errors = err.errors || [];
            return _.some(errors, function (error) {
                return error.reason === 'rateLimitExceeded';
            });
        }
    };
    return async.retryable(options, func.bind(ctx));
}
function Adapter(config) {
    this.credentials = config.credentials;
    var gceConfig = {
        projectId: this.credentials.project_id,
        credentials: this.credentials
    };
    this.compute = new Compute(gceConfig);
    this.zone = this.compute.zone(config.zone);
}
Adapter.prototype.createInstance = function (nodeName, config, callback) {
    var createVMWithRetry = wrapWithRetry(this.zone, this.zone.createVM);
    createVMWithRetry(nodeName, config, function (err, vm, operation, apiResponse) {
        return callback(err, apiResponse);
    });
};
Adapter.prototype.deleteInstance = function (nodeName, callback) {
    var vm = this.zone.vm(nodeName);
    var deleteVmWithRetry = wrapWithRetry(vm, vm.delete);
    deleteVmWithRetry(function (err, operation, apiResponse) {
        return callback(err, apiResponse);
    });
};
Adapter.prototype.stopInstance = function (nodeName, callback) {
    var vm = this.zone.vm(nodeName);
    var stopInstanceWithRetry = wrapWithRetry(vm, vm.stop);
    stopInstanceWithRetry(function (err, operation, apiResponse) {
        return callback(err, apiResponse);
    });
};
Adapter.prototype.waitForStatus = function (nodeName, status, timeout, callback) {
    var vm = this.zone.vm(nodeName);
    var options = {
        timeout: timeout || 300
    };
    var waitForStatusWithRetry = wrapWithRetry(vm, vm.waitFor);
    waitForStatusWithRetry(status, options, function (err, metadata) {
        return callback(err, metadata);
    });
};
Adapter.prototype.startInstance = function (nodeName, callback) {
    var vm = this.zone.vm(nodeName);
    var startInstanceWithRetry = wrapWithRetry(vm, vm.start);
    startInstanceWithRetry(function (err, operation, apiResponse) {
        return callback(err, apiResponse);
    });
};
Adapter.prototype.setMetadata = function (nodeName, metadata, callback) {
    var vm = this.zone.vm(nodeName);
    var setMetadataWithRetry = wrapWithRetry(vm, vm.setMetadata);
    setMetadataWithRetry(metadata, function (err, operation, apiResponse) {
        return callback(err, apiResponse);
    });
};
//# sourceMappingURL=Adapter.js.map