'use strict';
var self = deploymentSpec;
module.exports = self;
var rootlessDockerDataDir = '/home/rootless/.local/share/docker';
function deploymentSpec(externalBag, callback) {
    var bag = {
        jfrogDir: '/var/opt/jfrog/pipelines',
        reqKickDir: '/var/opt/jfrog/pipelines/reqKick',
        customCertsDir: '/var/opt/jfrog/pipelines/var/etc/security/keys/trusted',
        customCertsEnabled: externalBag.customCertsEnabled,
        customCertsConfigMapName: externalBag.customCertsConfigMapName,
        deploymentName: externalBag.deploymentName,
        projectId: externalBag.projectId,
        nodePoolId: externalBag.nodePoolId,
        nodeId: externalBag.nodeId,
        nodeName: externalBag.nodeName,
        nodeSelector: externalBag.nodeSelector,
        pvcName: externalBag.pvcName,
        dindParams: externalBag.dindParams,
        reqkickParams: externalBag.reqkickParams,
        runMode: externalBag.runMode,
        architecture: externalBag.architecture,
        operatingSystem: externalBag.operatingSystem,
        buildPlaneVersion: externalBag.buildPlaneVersion,
        apiExternalUrl: externalBag.apiExternalUrl,
        baseUrlUI: externalBag.baseUrlUI,
        secretName: externalBag.secretName,
        configMapName: externalBag.configMapName,
        nodePollerIntervalMS: externalBag.nodePollerIntervalMS,
        token: externalBag.token,
        imagePullSecret: externalBag.imagePullSecret,
    };
    bag.who = util.format('marshaller|_common|k8s|%s|jFrogPipelinesSessionId: ' +
        '%s', self.name, externalBag.jFrogPipelinesSessionId);
    logger.debug(bag.who, 'Starting');
    async.series([
        _prepDeploymentSpec.bind(null, bag)
    ], function (err) {
        if (err)
            logger.warn(bag.who, 'Failed to generate deployment spec');
        else
            logger.debug(bag.who, 'Successfully generated deployment spec');
        return callback(err, bag.deployment);
    });
}
function _prepDeploymentSpec(bag, next) {
    var who = self.name + '|' + _prepDeploymentSpec.name;
    logger.trace(who, 'Inside');
    var dockerConfigDaemonCommands = '';
    var dockerConfigCertsCommands = '';
    bag.deployment = {
        name: bag.deploymentName,
        spec: {
            "apiVersion": "apps/v1",
            "kind": "Deployment",
            "metadata": {
                "name": bag.deploymentName
            },
            "spec": {
                "replicas": 1,
                "selector": {
                    "matchLabels": {
                        "project-id": JSON.stringify(bag.projectId),
                        "nodepool-id": JSON.stringify(bag.nodePoolId),
                        "nodepool-node-id": JSON.stringify(bag.nodeId),
                        "node-name": bag.nodeName
                    }
                },
                "template": {
                    "metadata": {
                        "labels": {
                            "project-id": JSON.stringify(bag.projectId),
                            "nodepool-id": JSON.stringify(bag.nodePoolId),
                            "nodepool-node-id": JSON.stringify(bag.nodeId),
                            "node-name": bag.nodeName,
                            "node-affinity": "k8s-node-pool"
                        }
                    },
                    "spec": {
                        "nodeSelector": bag.nodeSelector,
                        "affinity": {
                            "podAntiAffinity": {
                                "requiredDuringSchedulingIgnoredDuringExecution": []
                            }
                        },
                        "volumes": [
                            {
                                "name": "dind-certs",
                                "emptyDir": {}
                            },
                            {
                                "name": "jfrog-pipelines",
                                "emptyDir": {}
                            },
                            {
                                "name": "docker-volume",
                                "persistentVolumeClaim": {
                                    "claimName": bag.pvcName
                                }
                            }
                        ],
                        "securityContext": {
                            "fsGroup": 1000
                        },
                        "initContainers": [
                            {
                                "name": "init",
                                "image": bag.reqkickParams.image,
                                "imagePullPolicy": "IfNotPresent",
                                "env": [
                                    {
                                        "name": "PIPELINES_NODE_API_TOKEN",
                                        "valueFrom": {
                                            "secretKeyRef": {
                                                "name": bag.secretName,
                                                "key": "token"
                                            }
                                        }
                                    }
                                ],
                                "command": [
                                    'sh', '-c',
                                    `cp -vpfr /jfrog-init/* /var/opt/jfrog/pipelines; ` +
                                        `chown -R 1000:1000 ${rootlessDockerDataDir}; ` +
                                        `curl -sL -X PUT -H "Authorization: Bearer ` +
                                        `$PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" ` +
                                        `-d '{"lastInitializedAt": "'$(date -u +"%FT%TZ")'"}' ` +
                                        `${bag.apiExternalUrl}/nodes/${bag.nodeId} ` +
                                        `-w "%{http_code}";`
                                ],
                                "volumeMounts": [
                                    {
                                        "name": "jfrog-pipelines",
                                        "mountPath": bag.jfrogDir
                                    },
                                    {
                                        "name": "docker-volume",
                                        "mountPath": rootlessDockerDataDir
                                    }
                                ]
                            },
                        ],
                        "containers": [
                            {
                                "name": "pipelines-dind",
                                "image": bag.dindParams.image,
                                "resources": bag.dindParams.resources,
                                "imagePullPolicy": "IfNotPresent",
                                "securityContext": {
                                    "privileged": true,
                                    "runAsUser": 1000,
                                    "runAsGroup": 1000
                                },
                                "volumeMounts": [
                                    {
                                        "name": "dind-certs",
                                        "mountPath": "/certs"
                                    },
                                    {
                                        "name": "jfrog-pipelines",
                                        "mountPath": bag.jfrogDir
                                    },
                                    {
                                        "name": "docker-volume",
                                        "mountPath": rootlessDockerDataDir
                                    }
                                ]
                            },
                            {
                                "name": "reqkick",
                                "image": bag.reqkickParams.image,
                                "resources": bag.reqkickParams.resources,
                                "imagePullPolicy": "IfNotPresent",
                                "env": [
                                    {
                                        "name": "DOCKER_HOST",
                                        "value": "tcp://localhost:2376"
                                    },
                                    {
                                        "name": "DOCKER_CERT_PATH",
                                        "value": "/certs/client"
                                    },
                                    {
                                        "name": "DOCKER_TLS_VERIFY",
                                        "value": "1"
                                    },
                                    {
                                        "name": "NODE_ID",
                                        "value": JSON.stringify(bag.nodeId)
                                    },
                                    {
                                        "name": "RUN_MODE",
                                        "value": bag.runMode
                                    },
                                    {
                                        "name": "PROJECT_ID",
                                        "value": JSON.stringify(bag.projectId)
                                    },
                                    {
                                        "name": "PIPELINES_NODE_ARCHITECTURE",
                                        "value": bag.architecture
                                    },
                                    {
                                        "name": "PIPELINES_NODE_OPERATING_SYSTEM",
                                        "value": bag.operatingSystem
                                    },
                                    {
                                        "name": "BASE_DIR",
                                        "value": bag.jfrogDir
                                    },
                                    {
                                        "name": "REQKICK_DIR",
                                        "value": bag.jfrogDir + "/reqKick"
                                    },
                                    {
                                        "name": "REQEXEC_BIN_PATH",
                                        "value": bag.jfrogDir + "/reqExec/dist/main/main"
                                    },
                                    {
                                        "name": "REQEXEC_DIR",
                                        "value": bag.jfrogDir + "/reqExec"
                                    },
                                    {
                                        "name": "EXECTEMPLATES_DIR",
                                        "value": bag.reqKickDir + "/node_modules/@jfrog-pipelines/core/execTemplates"
                                    },
                                    {
                                        "name": "EXTENSIONS_DIR",
                                        "value": bag.jfrogDir + "/extensions"
                                    },
                                    {
                                        "name": "REPORTS_DIR",
                                        "value": bag.jfrogDir + "/reports"
                                    },
                                    {
                                        "name": "BUILD_PLANE_VERSION",
                                        "value": bag.buildPlaneVersion
                                    },
                                    {
                                        "name": "PIPELINES_CORE_SERVICES_API_EXTERNALURL",
                                        "value": bag.apiExternalUrl
                                    },
                                    {
                                        "name": "PIPELINES_SHARED_ARTIFACTORY_BASEURLUI",
                                        "value": bag.baseUrlUI
                                    },
                                    {
                                        "name": "PIPELINES_NODE_API_TOKEN",
                                        "valueFrom": {
                                            "secretKeyRef": {
                                                "name": bag.secretName,
                                                "key": "token"
                                            }
                                        }
                                    },
                                    {
                                        "name": "IS_K8S_BUILD_PLANE",
                                        "value": "true"
                                    },
                                    {
                                        "name": "REQKICK_OS",
                                        "value": "UBI_8"
                                    },
                                    {
                                        "name": "NODE_POLLER_INTERVAL_MS",
                                        "value": JSON.stringify(bag.nodePollerIntervalMS)
                                    },
                                    {
                                        "name": "CUSTOM_CERTS_ENABLED",
                                        "value": JSON.stringify(bag.customCertsEnabled)
                                    }
                                ],
                                "volumeMounts": [
                                    {
                                        "name": "dind-certs",
                                        "mountPath": "/certs"
                                    },
                                    {
                                        "name": "jfrog-pipelines",
                                        "mountPath": bag.jfrogDir
                                    }
                                ]
                            }
                        ]
                    }
                }
            }
        }
    };
    if (!_.isEmpty(bag.configMapName)) {
        bag.deployment.spec.spec.template.spec.volumes.push({
            "name": "docker-config-volume-source",
            "configMap": {
                "name": bag.configMapName
            }
        });
        bag.deployment.spec.spec.template.spec.initContainers[0].volumeMounts.push({
            "name": "docker-config-volume-source",
            "mountPath": "/jfrog-pipelines/tmp/daemon.json",
            "subPath": "daemon.json"
        });
        bag.deployment.spec.spec.template.spec.volumes.push({
            "name": "docker-config-volume-target",
            "emptyDir": {}
        });
        bag.deployment.spec.spec.template.spec.initContainers[0].volumeMounts.push({
            "name": "docker-config-volume-target",
            "mountPath": "/jfrog-pipelines-target",
        });
        bag.deployment.spec.spec.template.spec.containers[0].volumeMounts.push({
            "name": "docker-config-volume-target",
            "mountPath": "/home/rootless/.config/docker",
        });
        dockerConfigDaemonCommands =
            `echo "Copying docker deamon configuration for insecure registries"; ` +
                `cp -vpf /jfrog-pipelines/tmp/daemon.json /jfrog-pipelines-target/daemon.json; ` +
                `chown -R 1000:1000 /jfrog-pipelines-target; `;
    }
    if (bag.customCertsEnabled) {
        var customCertsFile = bag.customCertsDir + '/ca.crt';
        bag.deployment.spec.spec.template.spec.volumes.push({
            "name": "custom-certs",
            "configMap": {
                "name": bag.customCertsConfigMapName
            }
        });
        bag.deployment.spec.spec.template.spec.volumes.push({
            "name": "custom-certs-dind",
            "configMap": {
                "name": bag.customCertsConfigMapName
            }
        });
        bag.deployment.spec.spec.template.spec.initContainers[0].volumeMounts.push({
            "name": "custom-certs",
            "mountPath": customCertsFile,
            "subPath": "ca.crt"
        });
        bag.deployment.spec.spec.template.spec.containers[0].volumeMounts.push({
            "name": "custom-certs-dind",
            "mountPath": "/etc/ssl/certs/custom-ca.crt",
            "subPath": "ca.crt"
        });
        bag.deployment.spec.spec.template.spec.containers[0].volumeMounts.push({
            "name": "custom-certs",
            "mountPath": customCertsFile,
            "subPath": "ca.crt"
        });
        bag.deployment.spec.spec.template.spec.containers[1].volumeMounts.push({
            "name": "custom-certs",
            "mountPath": customCertsFile,
            "subPath": "ca.crt"
        });
        dockerConfigCertsCommands =
            `echo "Copying custom certificate"; ` +
                `cp -vpfr ${customCertsFile} ` +
                `/usr/share/pki/ca-trust-source/anchors/; ` +
                `echo "Installing custom certificate"; ` +
                `update-ca-trust extract; `;
        bag.deployment.spec.spec.template.spec.containers[1].env.push({
            "name": "CUSTOM_CERTS_DIR",
            "value": bag.customCertsDir
        }, {
            "name": "NODE_EXTRA_CA_CERTS",
            "value": customCertsFile
        });
    }
    bag.deployment.spec.spec.template.spec.initContainers[0].command = [
        'sh', '-c',
        `cp -vpfr /jfrog-init/* /var/opt/jfrog/pipelines; ` +
            `chown -R 1000:1000 ${rootlessDockerDataDir}; ` +
            `${dockerConfigDaemonCommands}` +
            `${dockerConfigCertsCommands}` +
            `echo "Setting node initializedAt timestamp"; ` +
            `curl -sL -X PUT -H "Authorization: Bearer ` +
            `$PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" ` +
            `-d '{"lastInitializedAt": "'$(date -u +"%FT%TZ")'"}' ` +
            `${bag.apiExternalUrl}/nodes/${bag.nodeId} ` +
            `-w "%{http_code}";`
    ];
    if (bag.imagePullSecret) {
        bag.deployment.spec.spec.template.spec.imagePullSecrets = [
            {
                "name": bag.imagePullSecret
            }
        ];
    }
    if (global.config.isSaas && global.config.runOnePodInOneNode) {
        bag.deployment.spec.spec
            .template.spec.affinity
            .podAntiAffinity
            .requiredDuringSchedulingIgnoredDuringExecution
            .push({
            "labelSelector": {
                "matchExpressions": [
                    {
                        "key": "node-affinity",
                        "operator": "In",
                        "values": [
                            "k8s-node-pool"
                        ]
                    }
                ]
            },
            "topologyKey": "kubernetes.io/hostname"
        });
    }
    if (bag.runMode === 'devmode') {
        _.each(bag.deployment.spec.spec.template.spec.initContainers, function (container) {
            container.imagePullPolicy = 'Always';
        });
        _.each(bag.deployment.spec.spec.template.spec.containers, function (container) {
            container.imagePullPolicy = 'Always';
        });
    }
    return next();
}
//# sourceMappingURL=deploymentSpec.js.map