'use strict';
var _ = require('underscore');
const OS_FAMILY_MACOS = 'MacOS';
exports.OS_FAMILY_MACOS = OS_FAMILY_MACOS;
var supportedNodes = [
    {
        os: 'Ubuntu_18.04',
        architectures: 'x86_64',
        family: 'Linux',
        artifactFileExtension: 'deb',
        scriptFileExtension: 'sh',
        platformBaseImage: 'u18',
    },
    {
        os: 'Ubuntu_20.04',
        architectures: 'x86_64',
        family: 'Linux',
        artifactFileExtension: 'deb',
        scriptFileExtension: 'sh',
        platformBaseImage: 'u20',
    },
    {
        os: 'Ubuntu_20.04',
        architectures: 'ARM64',
        family: 'Linux',
        artifactFileExtension: 'deb',
        scriptFileExtension: 'sh',
        platformBaseImage: 'u20',
    },
    {
        os: 'CentOS_7',
        architectures: 'x86_64',
        family: 'Linux',
        artifactFileExtension: 'rpm',
        scriptFileExtension: 'sh',
        platformBaseImage: 'c7',
    },
    {
        os: 'AmazonLinux_2',
        architectures: 'x86_64',
        family: 'Linux',
        artifactFileExtension: 'rpm',
        scriptFileExtension: 'sh',
        platformBaseImage: 'c8',
    },
    {
        os: 'RHEL_7',
        architectures: 'x86_64',
        family: 'Linux',
        artifactFileExtension: 'rpm',
        scriptFileExtension: 'sh',
        platformBaseImage: 'c7',
    },
    {
        os: 'RHEL_8',
        architectures: 'x86_64',
        family: 'Linux',
        artifactFileExtension: 'rpm',
        scriptFileExtension: 'sh',
        platformBaseImage: 'c8',
    },
    {
        os: 'WindowsServer_2019',
        architectures: 'x86_64',
        family: 'Windows',
        artifactFileExtension: 'tar.gz',
        scriptFileExtension: 'ps1',
        platformBaseImage: 'w19',
    },
    {
        os: 'MacOS_10.15',
        architectures: 'x86_64',
        family: OS_FAMILY_MACOS,
        artifactFileExtension: 'tar.gz',
        scriptFileExtension: 'sh',
        platformBaseImage: 'm10',
    },
    {
        os: 'MacOS_12',
        architectures: 'ARM64',
        family: OS_FAMILY_MACOS,
        artifactFileExtension: 'tar.gz',
        scriptFileExtension: 'sh',
        platformBaseImage: 'm12',
    },
];
var supportedNodesByArchitecture = _.groupBy(supportedNodes, 'architectures');
exports.supportedArchitectures = _.keys(supportedNodesByArchitecture);
exports.supportedOsFamily = _.pluck(supportedNodes, 'family').reduce(function (result, value) {
    return _.extend(result, { [value.toUpperCase()]: value });
}, {});
exports.supportedOsAndFamilyMap = _.reduce(supportedNodes, function (result, node) {
    return _.extend(result, { [node.os]: node.family });
}, {});
var supportedArchAndOsMap = {};
var buildPlaneArtifactFileExtensionMap = {};
var nodeInitScriptFileExtensionMap = {};
var nodePlatformBaseImageMap = {};
_.each(supportedNodesByArchitecture, function (value, key) {
    supportedArchAndOsMap[key] = value.map(function (node) {
        return node.os;
    });
    buildPlaneArtifactFileExtensionMap[key] = value.reduce(function (resValue, node) {
        return _.extend(resValue, { [node.os]: node.artifactFileExtension });
    }, {});
    nodeInitScriptFileExtensionMap[key] = value.reduce(function (resValue, node) {
        return _.extend(resValue, { [node.os]: node.scriptFileExtension });
    }, {});
    nodePlatformBaseImageMap[key] = value.reduce(function (resValue, node) {
        return _.extend(resValue, { [node.os]: node.platformBaseImage });
    }, {});
});
exports.supportedArchAndOsMap = supportedArchAndOsMap;
exports.buildPlaneArtifactFileExtensionMap = buildPlaneArtifactFileExtensionMap;
exports.nodeInitScriptFileExtensionMap = nodeInitScriptFileExtensionMap;
exports.nodePlatformBaseImageMap = nodePlatformBaseImageMap;
var amazonKeys = {
    'Linux': {
        'supportedFields': ['sshUser', 'sshPort', 'keyPairName',
            'securityGroupId', 'subnetId', 'instanceSize'],
        'requiredFields': ['instanceSize', 'keyPairName'],
        'supportedInstances': ['c4.large', 'c4.xlarge', 'c4.2xlarge'],
        'armSupportedInstances': ['t4g.micro']
    },
    'Mac': {
        'supportedFields': ['sshUser', 'sshPort', 'keyPairName',
            'securityGroupId', 'subnetId', 'instanceSize'],
        'requiredFields': ['instanceSize', 'keyPairName'],
        'supportedInstances': ['mac1.metal']
    },
    'Windows': {
        'supportedFields': ['sshUser', 'sshPort', 'keyPairName',
            'securityGroupId', 'subnetId', 'instanceSize'],
        'requiredFields': ['instanceSize', 'keyPairName'],
        'supportedInstances': ['c4.large', 'c4.xlarge', 'c4.2xlarge']
    }
};
var gcloudKey = {
    'supportedFields': ['subnetName', 'instanceSize', 'networkTags', 'zone',
        'assignPublicIp'],
    'requiredFields': ['instanceSize', 'zone'],
    'supportedInstances': ['n1-standard-1', 'n1-standard-2', 'n1-standard-4']
};
var azureKeys = {
    'Linux': {
        'supportedFields': ['publicSshKey', 'subscriptionId', 'resourceGroupName',
            'instanceSize', 'subnetName', 'securityGroupName', 'vnetName'],
        'requiredFields': ['publicSshKey', 'subscriptionId',
            'resourceGroupName', 'instanceSize', 'subnetName', 'vnetName'],
        'supportedInstanceSizes': ['Standard_F2s', 'Standard_F4s',
            'Standard_F8s']
    },
    'Windows': {
        'supportedFields': ['adminUsername', 'adminPassword', 'subscriptionId',
            'resourceGroupName', 'instanceSize', 'subnetName', 'securityGroupName',
            'vnetName'],
        'requiredFields': ['subscriptionId', 'resourceGroupName', 'instanceSize',
            'subnetName', 'vnetName'],
        'supportedInstanceSizes': ['Standard_F2s', 'Standard_F4s',
            'Standard_F8s']
    }
};
exports.providerMetadataMap = {
    amazonKeys: {
        'x86_64': {
            'Ubuntu_18.04': {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.supportedInstances
            },
            'Ubuntu_20.04': {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.supportedInstances
            },
            'CentOS_7': {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.supportedInstances
            },
            'RHEL_7': {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.supportedInstances
            },
            'RHEL_8': {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.supportedInstances
            },
            'AmazonLinux_2': {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.supportedInstances
            },
            'MacOS_10.15': {
                supportedFields: amazonKeys.Mac.supportedFields,
                requiredFields: amazonKeys.Mac.requiredFields,
                supportedInstanceSizes: amazonKeys.Mac.supportedInstances
            },
            'WindowsServer_2019': {
                supportedFields: amazonKeys.Windows.supportedFields,
                requiredFields: amazonKeys.Windows.requiredFields,
                supportedInstanceSizes: amazonKeys.Windows.supportedInstances
            }
        },
        'ARM64': {
            'Ubuntu_20.04': {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.armSupportedInstances
            },
            CentOS_7: {
                supportedFields: amazonKeys.Linux.supportedFields,
                requiredFields: amazonKeys.Linux.requiredFields,
                supportedInstanceSizes: amazonKeys.Linux.armSupportedInstances
            }
        }
    },
    gcloudKey: {
        'x86_64': {
            'Ubuntu_18.04': {
                supportedFields: gcloudKey.supportedFields,
                requiredFields: gcloudKey.requiredFields,
                supportedInstanceSizes: gcloudKey.supportedInstances
            },
            'Ubuntu_20.04': {
                supportedFields: gcloudKey.supportedFields,
                requiredFields: gcloudKey.requiredFields,
                supportedInstanceSizes: gcloudKey.supportedInstances
            },
            'CentOS_7': {
                supportedFields: gcloudKey.supportedFields,
                requiredFields: gcloudKey.requiredFields,
                supportedInstanceSizes: gcloudKey.supportedInstances
            },
        }
    },
    azureKeys: {
        'x86_64': {
            'Ubuntu_18.04': {
                supportedFields: azureKeys.Linux.supportedFields,
                requiredFields: azureKeys.Linux.requiredFields,
                supportedInstanceSizes: azureKeys.Linux.supportedInstanceSizes,
                osType: 'Linux'
            },
            'Ubuntu_20.04': {
                supportedFields: azureKeys.Linux.supportedFields,
                requiredFields: azureKeys.Linux.requiredFields,
                supportedInstanceSizes: azureKeys.Linux.supportedInstanceSizes,
                osType: 'Linux'
            },
            'CentOS_7': {
                supportedFields: azureKeys.Linux.supportedFields,
                requiredFields: azureKeys.Linux.requiredFields,
                supportedInstanceSizes: azureKeys.Linux.supportedInstanceSizes,
                osType: 'Linux'
            },
            'WindowsServer_2019': {
                supportedFields: azureKeys.Windows.supportedFields,
                requiredFields: azureKeys.Windows.requiredFields,
                supportedInstanceSizes: azureKeys.Windows.supportedInstanceSizes,
                osType: 'Windows'
            }
        }
    }
};
exports.getProviderMetadataMap = function () {
    if (global.config && global.config.instanceType) {
        if (!amazonKeys.Linux.supportedInstances.includes(global.config.instanceType)) {
            amazonKeys.Linux.supportedInstances.unshift(global.config.instanceType);
        }
        if (!amazonKeys.Windows.supportedInstances.includes(global.config.instanceType)) {
            amazonKeys.Windows.supportedInstances.unshift(global.config.instanceType);
        }
    }
    return providerMetadataMap;
};
exports.isSupportedArchitecture = function (architecture) {
    var architectures = this || exports;
    return architectures.supportedArchitectures.some(function (supportedArchitecture) {
        return supportedArchitecture === architecture;
    });
};
exports.isSupportedOperatingSystem = function (architecture, operatingSystem) {
    var self = this || exports;
    var isSupportedOS = false;
    isSupportedOS = self.supportedArchAndOsMap &&
        self.supportedArchAndOsMap[architecture] &&
        self.supportedArchAndOsMap[architecture].some(function (supportedOperatingSystem) {
            return supportedOperatingSystem === operatingSystem;
        });
    return !!isSupportedOS;
};
exports.getBuildPlaneArtifactExtension = function (architecture, operatingSystem) {
    var self = this || exports;
    var extension = '';
    extension = self.buildPlaneArtifactFileExtensionMap[architecture] &&
        self.buildPlaneArtifactFileExtensionMap[architecture][operatingSystem];
    return extension;
};
exports.getScriptFileExtension = function (architecture, operatingSystem) {
    var self = this || exports;
    var extension = '';
    extension = self.nodeInitScriptFileExtensionMap[architecture] &&
        self.nodeInitScriptFileExtensionMap[architecture][operatingSystem];
    return extension;
};
exports.getBaseImage = function (architecture, operatingSystem) {
    var self = this || exports;
    var image = '';
    image = self.nodePlatformBaseImageMap[architecture] &&
        self.nodePlatformBaseImageMap[architecture][operatingSystem];
    return image;
};
exports.getProviderSupportedFields = function (provider, architecture, operatingSystem) {
    var self = this || exports;
    var supportedFields = '';
    supportedFields = self.getProviderMetadataMap()[provider] &&
        self.getProviderMetadataMap()[provider][architecture] &&
        self.getProviderMetadataMap()[provider][architecture][operatingSystem] &&
        self.getProviderMetadataMap()[provider][architecture][operatingSystem].
            supportedFields;
    return supportedFields;
};
exports.getProviderRequiredFields = function (provider, architecture, operatingSystem) {
    var self = this || exports;
    var requiredFields = '';
    requiredFields = self.getProviderMetadataMap()[provider] &&
        self.getProviderMetadataMap()[provider][architecture] &&
        self.getProviderMetadataMap()[provider][architecture][operatingSystem] &&
        self.getProviderMetadataMap()[provider][architecture][operatingSystem].
            requiredFields;
    return requiredFields;
};
exports.getProviderInstanceSizes = function (provider, architecture, operatingSystem) {
    var self = this || exports;
    var instanceSizes = '';
    instanceSizes = self.getProviderMetadataMap()[provider] &&
        self.getProviderMetadataMap()[provider][architecture] &&
        self.getProviderMetadataMap()[provider][architecture][operatingSystem] &&
        self.getProviderMetadataMap()[provider][architecture][operatingSystem].
            supportedInstanceSizes;
    return instanceSizes;
};
exports.getProviderData = function (provider, architecture, operatingSystem) {
    var self = this || exports;
    var providerMetadataMap = self.getProviderMetadataMap();
    return providerMetadataMap[provider] &&
        providerMetadataMap[provider][architecture] &&
        providerMetadataMap[provider][architecture][operatingSystem];
};
exports.areProviderSupportedFieldsValid = function (provider, architecture, operatingSystem, fields) {
    var self = this || exports;
    var providerMetadataMap = self.getProviderMetadataMap();
    if (providerMetadataMap[provider] &&
        providerMetadataMap[provider][architecture] &&
        providerMetadataMap[provider][architecture][operatingSystem])
        return _.isEmpty(_.difference(fields, providerMetadataMap[provider][architecture][operatingSystem].
            supportedFields));
    else
        return false;
};
exports.areProviderRequiredFieldsPresent = function (provider, architecture, operatingSystem, fields) {
    var self = this || exports;
    var providerMetadataMap = self.getProviderMetadataMap();
    if (providerMetadataMap[provider] &&
        providerMetadataMap[provider][architecture] &&
        providerMetadataMap[provider][architecture][operatingSystem])
        return _.isEmpty(_.difference(providerMetadataMap[provider][architecture][operatingSystem].
            requiredFields, fields));
    else
        return false;
};
exports.getScriptFileExtensionForOsFamily = function (osFamily) {
    var self = this || exports;
    var architecture = self.supportedArchitectures[0];
    var extension = '';
    var operatingSystem = _.findKey(self.supportedOsAndFamilyMap, function (value) {
        return value === osFamily;
    });
    extension = self.nodeInitScriptFileExtensionMap[architecture] &&
        self.nodeInitScriptFileExtensionMap[architecture][operatingSystem];
    return extension;
};
exports.isOsFamilyListValid = function (osList) {
    if (_.isEmpty(osList))
        return false;
    var self = this || exports;
    return _.every(osList, function (value) {
        return Object.values(self.supportedOsFamily).includes(value.os);
    });
};
//# sourceMappingURL=nodeMetadataMap.js.map