'use strict';
exports.WAITING = 4005;
exports.QUEUED = 4000;
exports.PROCESSING = 4001;
exports.READY = 4016;
exports.SUCCESS = 4002;
exports.SKIPPED = 4008;
exports.UNSTABLE = 4007;
exports.TIMEOUT = 4009;
exports.CANCELED = 4006;
exports.FAILED = 4003;
exports.STOPPED = 4010;
exports.DELETED = 4011;
exports.CACHED = 4012;
exports.CANCELLING = 4013;
exports.TIMINGOUT = 4014;
exports.names = [
    'WAITING', 'QUEUED', 'PROCESSING', 'SUCCESS', 'SKIPPED', 'UNSTABLE',
    'TIMEOUT', 'CANCELED', 'FAILED', 'STOPPED', 'DELETED', 'CACHED', 'CANCELLING',
    'TIMINGOUT', 'READY'
];
exports.statusPriorityMap = {
    'success': 1,
    'skipped': 2,
    'cancelled': 3,
    'timeout': 4,
    'unstable': 5,
    'error': 6,
    'failure': 7,
    'waiting': 8
};
exports.lookup = function (code, subset) {
    var statusCodes = (subset || this || exports), matchingName = null;
    statusCodes.names.some(function (statusCodeName) {
        if (statusCodes[statusCodeName] === code) {
            return (matchingName = statusCodeName);
        }
    });
    return matchingName;
};
exports.idle = createSubset('WAITING', 'QUEUED');
exports.processing = createSubset('PROCESSING');
exports.incomplete = createSubset('WAITING', 'QUEUED', 'PROCESSING', 'CANCELLING', 'TIMINGOUT');
exports.started = createSubset('QUEUED', 'PROCESSING');
exports.complete = createSubset('SUCCESS', 'SKIPPED', 'UNSTABLE', 'TIMEOUT', 'CANCELED', 'FAILED', 'STOPPED');
exports.successful = createSubset('SUCCESS', 'SKIPPED', 'STOPPED', 'DELETED');
exports.unsuccessful =
    createSubset('UNSTABLE', 'TIMEOUT', 'CANCELED', 'FAILED');
exports.buildGroup = createSubset('WAITING', 'PROCESSING', 'SUCCESS', 'SKIPPED', 'CANCELED', 'FAILED');
exports.buildItem = exports;
exports.activeCellStates = createSubset('QUEUED', 'PROCESSING', 'SUCCESS');
exports.pendingLookup = function (code) {
    return !!exports.incomplete.lookup(code);
};
exports.idleLookup = function (code) {
    return !!exports.idle.lookup(code);
};
exports.processingLookup = function (code) {
    return !!exports.processing.lookup(code);
};
exports.activeLookup = function (code) {
    return !!exports.activeCellStates.lookup(code);
};
exports.completedLookup = function (code) {
    return !!exports.complete.lookup(code);
};
exports.failedLookup = function (code) {
    return !!exports.unsuccessful.lookup(code);
};
exports.successLookup = function (code) {
    return !!exports.successful.lookup(code);
};
exports.extractList = function (statusNames) {
    var statusCodes = [];
    statusNames.forEach(function (statusName) {
        if (typeof exports[statusName] === 'number') {
            statusCodes.push(exports[statusName]);
        }
    });
    return statusCodes;
};
function createSubset() {
    var statusCodeSubset = {}, statusNames = Array.prototype.slice.call(arguments, 0);
    statusCodeSubset.names = statusNames;
    statusNames.forEach(function (statusName) {
        statusCodeSubset[statusName] = exports[statusName];
    });
    statusCodeSubset.lookup = exports.lookup;
    return statusCodeSubset;
}
//# sourceMappingURL=statusCodes.js.map