"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandFactory = void 0;
const utility_1 = require("@jfrog-pipelines/utility");
const NodeStatsCleanupHandler_1 = require("./nodeStats/NodeStatsCleanupHandler");
const NodeStatsCleanupCommand_1 = require("./nodeStats/NodeStatsCleanupCommand");
const NodeStatsCheckCommand_1 = require("./nodeStats/NodeStatsCheckCommand");
const NodeStatsCheckHandler_1 = require("./nodeStats/NodeStatsCheckHandler");
class CommandFactory {
    static getCommand(payload) {
        const commandPayload = payload.command;
        switch (commandPayload.actor) {
            case utility_1.Actor.nodeStats: {
                switch (commandPayload.operation) {
                    case utility_1.Operation.delete: {
                        return new NodeStatsCleanupCommand_1.NodeStatsCleanupCommand(commandPayload.operation);
                    }
                    case utility_1.Operation.check: {
                        return new NodeStatsCheckCommand_1.NodeStatsCheckCommand(commandPayload.operation);
                    }
                    default: {
                        throw new Error('Invalid operation');
                    }
                }
            }
            default: {
                throw new Error('Invalid actor');
            }
        }
    }
    static getHandler(command) {
        switch (command.constructor) {
            case NodeStatsCleanupCommand_1.NodeStatsCleanupCommand: {
                return new NodeStatsCleanupHandler_1.NodeStatsCleanupHandler();
            }
            case NodeStatsCheckCommand_1.NodeStatsCheckCommand: {
                return new NodeStatsCheckHandler_1.NodeStatsCheckHandler();
            }
            default: {
                throw new Error('Invalid command');
            }
        }
    }
}
exports.CommandFactory = CommandFactory;
//# sourceMappingURL=CommandFactory.js.map