"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildPlaneMessageService = void 0;
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const metadata_1 = require("@jfrog-pipelines/metadata");
const logger_1 = require("@jfrog-pipelines/logger");
const BuildPlaneMessageDao_1 = require("./BuildPlaneMessageDao");
class BuildPlaneMessageService {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('buildPlaneMessageService');
        this.buildPlaneDao = new BuildPlaneMessageDao_1.BuildPlaneMessageDao();
    }
    async getReadyMessageCount(nodePoolID) {
        const queryBuilder = new data_access_layer_1.SequelizeQueryBuilder({}).where('nodePoolId', nodePoolID).where('statusCode', metadata_1.READY);
        return this.buildPlaneDao.count(queryBuilder.build());
    }
    async getReadyMessages(nodePoolID) {
        const queryBuilder = new data_access_layer_1.SequelizeQueryBuilder({}).where('nodePoolId', nodePoolID).where('statusCode', metadata_1.READY);
        return this.buildPlaneDao.findAll(queryBuilder.build());
    }
    async resetBuildPlane(node) {
        const findQueryBuilder = new data_access_layer_1.SequelizeQueryBuilder({});
        findQueryBuilder.where('nodeId', node.id);
        const buildPlaneMessage = await this.buildPlaneDao.findOne(findQueryBuilder.build());
        if (!buildPlaneMessage) {
            return;
        }
        await this.buildPlaneDao.updateByInstance(buildPlaneMessage, {
            nodeId: null,
            queuedAt: null,
            statusCode: metadata_1.READY
        });
        this.logger.warn(`Successfully reseted buildPlaneMessage with id:${buildPlaneMessage.id}`);
    }
}
exports.BuildPlaneMessageService = BuildPlaneMessageService;
//# sourceMappingURL=BuildPlaneMessageService.js.map