"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const BuildPlaneImageService_1 = require("../../../buildPlaneImage/BuildPlaneImageService");
const UserRepository_1 = require("../../../../acl/userService/UserRepository");
const AwsRequestTransformer_1 = require("./../AwsRequestTransformer");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn(),
            getEventLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const nodePoolerIdleInterval = 1000;
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: {
            config: { runMode: 'dev', nodePollerIntervalMS: 15000, customCertsEnabled: false, noVerifySsl: false }
        }
    };
});
describe('AwsRequestTransformer', () => {
    let awsRequestTransformer;
    beforeEach(() => {
        awsRequestTransformer = new AwsRequestTransformer_1.AwsRequestTransformer('runMode', 'externalApiUrl', nodePoolerIdleInterval, false, true, 'customCertsData');
    });
    describe('getNodeCreateRequest', () => {
        test('should return an instance request object', async () => {
            jest
                .spyOn(BuildPlaneImageService_1.BuildPlaneImageService.prototype, 'getBuildPlaneImageById')
                .mockResolvedValueOnce({ imageId: '1' });
            jest
                .spyOn(UserRepository_1.UserRepository.prototype, 'getProjectById')
                .mockResolvedValueOnce({ name: 'projectName' });
            jest
                .spyOn(UserRepository_1.UserRepository.prototype, 'getUnifiedUiAndWwwUrl')
                .mockResolvedValueOnce({ wwwUrl: 'http://localhost/wwwUrl', rtUiUrl: 'http://localhost/rtUiUrl' });
            const instanceRequest = await awsRequestTransformer.getNodeCreateRequest({
                id: 1,
                buildPlaneImageId: 1,
                projectId: 1,
                projectIntegrationId: 1,
                name: 'nodePoolName',
                operatingSystem: 'Ubuntu_18.04',
                architecture: 'x86_64',
                providerMetadataPropertyBag: {}
            }, {
                id: 1,
                friendlyName: 'nodeFriendlyName',
                systemPropertyBag: {},
                providerMetadataPropertyBag: {
                    imageId: 'testImageId'
                }
            });
            expect(Buffer.from(instanceRequest.getStartupScriptData(), 'base64').toString('ascii')).toContain(`NODE_POLLER_INTERVAL_MS=${nodePoolerIdleInterval}`);
        });
    });
});
//# sourceMappingURL=AwsRequestTransformer.test.js.map