"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloud_1 = require("@jfrog-pipelines/cloud");
const UserRepository_1 = require("../../../../acl/userService/UserRepository");
const CloudServiceClient_1 = require("../CloudServiceClient");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: {
            config: {
                getCustom: (key) => {
                    if (key === 'runtime.saasEnvironment') {
                        return 'development';
                    }
                    if (key === 'runtime.saasCustomerName') {
                        return 'customer';
                    }
                    if (key === 'runtime.isSaas') {
                        return 'true';
                    }
                }
            }
        }
    };
});
jest.mock('@jfrog-pipelines/cloud');
describe('CloudServiceClient', () => {
    const cloudServiceClient = new CloudServiceClient_1.CloudServiceClient();
    describe('getNodeProvider', () => {
        it('should return a CloudProvider based on the project integration', async () => {
            const node = {
                projectIntegrationId: 'integrationId',
                id: 1
            };
            const projectIntegration = {
                formJSONValues: [{ label: 'key', value: 'value' }],
                masterIntegrationName: 'amazonKeys'
            };
            jest.spyOn(UserRepository_1.UserRepository.prototype, 'getProjectIntegrationById').mockResolvedValue(projectIntegration);
            const getProviderSpy = jest.spyOn(cloud_1.CloudFactory, 'getProvider');
            await cloudServiceClient.getNodeProvider(node);
            expect(getProviderSpy).toHaveBeenCalledWith('aws', { key: 'value' }, expect.anything());
            expect(cloud_1.InstanceVariables).toHaveBeenCalledTimes(1);
        });
        it('should throw an error for an invalid provider name', async () => {
            const node = {
                projectIntegrationId: 1
            };
            const projectIntegration = {
                formJSONValues: [{ label: 'key', value: 'value' }],
                masterIntegrationName: 'invalidProvider'
            };
            jest
                .spyOn(UserRepository_1.UserRepository.prototype, 'getProjectIntegrationById')
                .mockResolvedValue(projectIntegration);
            await expect(cloudServiceClient.getNodeProvider(node)).rejects.toThrow('Invalid provider name: undefined');
        });
    });
});
//# sourceMappingURL=CloudServiceClient.test.js.map