"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloud_1 = require("@jfrog-pipelines/cloud");
const BuildPlaneImageService_1 = require("../../../buildPlaneImage/BuildPlaneImageService");
const UserRepository_1 = require("../../../../acl/userService/UserRepository");
const GcloudRequestTransformer_1 = require("../GcloudRequestTransformer");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn(),
            getEventLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const nodePoolerIdleInterval = 1000;
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: {
            config: { runMode: 'dev', nodePollerIntervalMS: 15000, customCertsEnabled: false, noVerifySsl: false }
        }
    };
});
describe('GcloudRequestTransformer', () => {
    const nodeId = 1;
    const nodePoolId = 1;
    const projectId = 1;
    const projectIntegrationId = 1;
    const node = {
        id: nodeId,
        friendlyName: 'node-test',
        systemPropertyBag: {},
        providerMetadataPropertyBag: {
            imageId: 'bpimage',
            metadataPropertyBag: {
                projectName: 'bpiproject',
                imageName: 'bpiname'
            }
        }
    };
    const nodePool = {
        id: nodePoolId,
        providerMetadataPropertyBag: {
            instanceSize: 'n1-standard-1',
            subnetName: 'subnet'
        },
        operatingSystem: 'Ubuntu_18.04',
        projectId: projectId,
        projectIntegrationId: projectIntegrationId,
        name: 'nodePool1',
        architecture: 'x86_64'
    };
    const gcloudRequestTransformer = new GcloudRequestTransformer_1.GcloudRequestTransformer('dev', 'externalApiUrl', nodePoolerIdleInterval, false, true, 'customCertsData');
    it('should get node create request', async () => {
        jest
            .spyOn(BuildPlaneImageService_1.BuildPlaneImageService.prototype, 'getBuildPlaneImageById')
            .mockResolvedValueOnce({ imageId: '1' });
        jest
            .spyOn(UserRepository_1.UserRepository.prototype, 'getProjectById')
            .mockResolvedValueOnce({ name: 'projectName' });
        jest
            .spyOn(UserRepository_1.UserRepository.prototype, 'getUnifiedUiAndWwwUrl')
            .mockResolvedValueOnce({ wwwUrl: 'http://localhost/wwwUrl', rtUiUrl: 'http://localhost/rtUiUrl' });
        const instanceRequest = await gcloudRequestTransformer.getNodeCreateRequest(nodePool, node);
        expect(instanceRequest.getStartupScriptData()).toContain(`NODE_POLLER_INTERVAL_MS=${nodePoolerIdleInterval}`);
    });
    it('should throw error when node create request is made', async () => {
        const faultyNodePool = {
            id: nodePoolId,
            providerMetadataPropertyBag: {
                instanceSize: 'n1-standard-1',
                subnetName: 'subnet'
            },
            operatingSystem: 'Ubuntu_18.04',
            projectId: projectId,
            projectIntegrationId: projectIntegrationId,
            name: 'nodePool1',
            architecture: 'architect'
        };
        jest
            .spyOn(BuildPlaneImageService_1.BuildPlaneImageService.prototype, 'getBuildPlaneImageById')
            .mockResolvedValueOnce({ imageId: '1' });
        jest
            .spyOn(UserRepository_1.UserRepository.prototype, 'getProjectById')
            .mockResolvedValueOnce({ name: 'projectName' });
        jest
            .spyOn(UserRepository_1.UserRepository.prototype, 'getUnifiedUiAndWwwUrl')
            .mockResolvedValueOnce({ wwwUrl: 'http://localhost/wwwUrl', rtUiUrl: 'http://localhost/rtUiUrl' });
        await expect(gcloudRequestTransformer.getNodeCreateRequest(faultyNodePool, node)).rejects.toThrow(Error);
    });
    it('should get node delete request', () => {
        expect(gcloudRequestTransformer.getNodeDeleteRequest(node)).toBeInstanceOf(cloud_1.TerminateInstanceRequest);
    });
    it('should get node transition request', () => {
        expect(gcloudRequestTransformer.getNodeTransitionRequest(node)).toBeInstanceOf(cloud_1.InstanceStateRequest);
    });
});
//# sourceMappingURL=GcloudRequestTransformer.test.js.map