#!/bin/bash -e
# Exporting env variables required for booting reqKick inside EC2 instance
# NOTE: this file cannot be more than 16KB
export JFROG_DIR="/var/opt/jfrog/pipelines"
export REQKICK_DIR="$JFROG_DIR/reqKick"
export EXECTEMPLATES_DIR="$REQKICK_DIR/node_modules/@jfrog-pipelines/core/execTemplates"
export EXTENSIONS_DIR="$JFROG_DIR/extensions"
export REQEXEC_DIR="$JFROG_DIR/reqExec"
export REPORTS_DIR="$JFROG_DIR/reports"
export NODEINIT_DIR="$JFROG_DIR/nodeInit"
export REQKICK_CONFIG_DIR="$JFROG_DIR/var/etc/reqKick"
export REQKICK_SERVICE_NAME="pipelines-reqKick"
export CUSTOM_CERTS_DIR="$JFROG_DIR/var/etc/security/keys/trusted"
export CUSTOM_CERTS_FILE_LOC="/etc/ssl/certs/ca-bundle.crt"
export NODE_OPERATING_SYSTEM="<%= operatingSystem %>"
export NODE_ARCHITECTURE="<%= architecture %>"
export RUN_MODE="<%= runMode %>"
export NODE_ID="<%= nodeId %>"
export PROJECT_ID="<%= projectId %>"
export BUILD_PLANE_VERSION="<%= buildPlaneVersion %>"
export PIPELINES_SHARED_ARTIFACTORY_BASEURLUI="<%= baseUrlUI %>"
export BUILDPLANE_RPM_DOWNLOAD_URL="<%= buildPlaneArtifactDownloadUrl %>"
export PIPELINES_CORE_SERVICES_WWW_EXTERNALURL="<%= wwwUrl %>"
export PIPELINES_CORE_SERVICES_API_EXTERNALURL="<%= apiExternalUrl %>"
export CONFIGURE_NODE=false
export ENABLE_SWAP=false
export BOOT_BUILD_AGENT=true
export INSECURE_DOCKER_REGISTRIES='<%= insecureDockerRegistries %>'
export PIPELINES_NODE_API_TOKEN='<%= token %>'
export NODE_POLLER_INTERVAL_MS=<%= nodePollerIntervalMS %>
export NO_VERIFY_SSL=<%= noVerifySsl %>
export CUSTOM_CERTS_DATA=<%= customCertsData %>
export CUSTOM_CERTS_ENABLED=<%= customCertsEnabled %>

CURL_OPTS=""
if [ "$CUSTOM_CERTS_ENABLED" == true ]; then
  mkdir -p $CUSTOM_CERTS_DIR
  echo -e $CUSTOM_CERTS_DATA > $CUSTOM_CERTS_DIR/ca.crt
  cp $CUSTOM_CERTS_DIR/ca.crt /usr/share/pki/ca-trust-source/anchors/
  update-ca-trust extract
elif [ "$NO_VERIFY_SSL" == true ]; then
  CURL_OPTS="--insecure"
fi

response_code=$(curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -I $BUILDPLANE_RPM_DOWNLOAD_URL $CURL_OPTS -o /dev/null -w "%{http_code}" -s -L)
if [ "$response_code" != "200" ]; then
  echo "Unable to connect to $BUILDPLANE_RPM_DOWNLOAD_URL"
  echo "Response code: $response_code, exiting"
  exit 1
fi

curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" $BUILDPLANE_RPM_DOWNLOAD_URL $CURL_OPTS --output buildPlane.rpm

rpm -i --prefix=$JFROG_DIR --force buildPlane.rpm

source $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh

init_time=$(date -u +"%FT%TZ")
api_response_code=$(curl -s $CURL_OPTS -X PUT -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" -d '{"lastInitializedAt":"'$init_time'"}' $PIPELINES_CORE_SERVICES_API_EXTERNALURL"/nodes/"$NODE_ID -o -l -i -w "%{http_code}")