#!/bin/bash -e
# Exporting env variables required for booting reqKick inside EC2 instance
# NOTE: this file cannot be more than 16KB
export JFROG_DIR="/var/opt/jfrog/pipelines"
export REQKICK_DIR="$JFROG_DIR/reqKick"
export EXECTEMPLATES_DIR="$REQKICK_DIR/node_modules/@jfrog-pipelines/core/execTemplates"
export EXTENSIONS_DIR="$JFROG_DIR/extensions"
export REQEXEC_DIR="$JFROG_DIR/reqExec"
export REPORTS_DIR="$JFROG_DIR/reports"
export NODEINIT_DIR="$JFROG_DIR/nodeInit"
export REQKICK_CONFIG_DIR="$JFROG_DIR/var/etc/reqKick"
export REQKICK_SERVICE_NAME="com.jfrog.pipelines.reqKick"
export CUSTOM_CERTS_DIR="$JFROG_DIR/var/etc/security/keys/trusted"
export CUSTOM_CERTS_FILE_LOC="/etc/ssl/certs/ca-certificates.crt"
export NODE_OPERATING_SYSTEM="<%= operatingSystem %>"
export NODE_ARCHITECTURE="<%= architecture %>"
export RUN_MODE="<%= runMode %>"
export NODE_ID="<%= nodeId %>"
export PROJECT_ID="<%= projectId %>"
export BUILD_PLANE_VERSION="<%= buildPlaneVersion %>"
export PIPELINES_SHARED_ARTIFACTORY_BASEURLUI="<%= baseUrlUI %>"
export PIPELINES_CORE_SERVICES_API_EXTERNALURL="<%= apiExternalUrl %>"
export CONFIGURE_NODE=false
export BOOT_BUILD_AGENT=true
export INSECURE_DOCKER_REGISTRIES='<%= insecureDockerRegistries %>'
export PIPELINES_NODE_API_TOKEN='<%= token %>'
export NODE_POLLER_INTERVAL_MS=<%= nodePollerIntervalMS %>
export NO_VERIFY_SSL=<%= noVerifySsl %>
export CUSTOM_CERTS_DATA=<%= customCertsData %>
export CUSTOM_CERTS_ENABLED=<%= customCertsEnabled %>
export BUILDPLANE_TAR_DOWNLOAD_URL="<%= buildPlaneArtifactDownloadUrl %>"

if ! command -v curl >/dev/null; then
  echo "curl not found, exiting"
  exit 1
fi

CURL_OPTS=""
if [ "$CUSTOM_CERTS_ENABLED" == true ]; then
  mkdir -p $CUSTOM_CERTS_DIR
  echo -e $CUSTOM_CERTS_DATA > $CUSTOM_CERTS_DIR/ca.crt
  security add-trusted-cert -d -r trustRoot -k /Library/Keychains/System.keychain $CUSTOM_CERTS_DIR/ca.crt
elif [ "$NO_VERIFY_SSL" == true ]; then
  CURL_OPTS="--insecure"
fi

response_code=""

while [ "$response_code" != "200" ]; do
  {
    response_code=$(curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -I $BUILDPLANE_TAR_DOWNLOAD_URL $CURL_OPTS -o /dev/null -w "%{http_code}" -s -L)
    [ $response_code -eq 200 ] && break;
  } || {
    echo "$response_code retrying connection in 30 seconds..."
    sleep 30
  }
done

mkdir -p $JFROG_DIR

while true; do
  {
    response_code=$(curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" $BUILDPLANE_TAR_DOWNLOAD_URL $CURL_OPTS --output $JFROG_DIR/buildPlane.tar.gz -L -s -w "%{http_code}")
    [ $response_code -eq 200 ] && break;
  } || {
    echo "$response_code retrying download in 30 seconds..."
    sleep 30
  }
done

tar -xf $JFROG_DIR/buildPlane.tar.gz -C "$JFROG_DIR"

rm $JFROG_DIR/buildPlane.tar.gz

sudo -E $NODEINIT_DIR/<%= architecture %>/<%= operatingSystem %>/boot.sh

init_time=$(date -u +"%FT%TZ")
api_response_code=$(curl -s $CURL_OPTS -X PUT -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" -d '{"lastInitializedAt":"'$init_time'"}' $PIPELINES_CORE_SERVICES_API_EXTERNALURL"/nodes/"$NODE_ID -o -l -i -w "%{http_code}")