node_status_handler() {
    # echo "An error occurred: $1"
    # Perform any necessary actions to handle the error

    # Make the curl call to report the error
    timestamp=$(date '+%s')
    consoleID=$(uuidgen)
    curl --location --request POST "$PIPELINES_SHARED_ARTIFACTORY_BASEURLUI/pipelines/api/v1/nodeConsoles" \
    --header "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" \
    --header 'Content-Type: application/json' \
    --data "{
        \"nodeConsoleModels\": [
            {
                \"nodeId\": \"$NODE_ID\",
                \"consoleId\": \"$consoleID\",
                \"parentConsoleId\": \"root\",
                \"timestamp\": \"$timestamp\",
                \"projectId\": \"$PROJECT_ID\",
                \"type\": \"msg\",
                \"message\": \"$1\",
                \"timestampEndedAt\": null,
                \"isSuccess\": false,
                \"isShown\": null
            }
        ]
    }"
}

check_buildplane_url_status() {
  local url=$1

  node_status_handler "Checking the URL $url"
  response_code=$(curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -I "$url" $CURL_OPTS -o /dev/null -w "%{http_code}" -s -L)
  
  if [ "$response_code" != "200" ]; then
    node_status_handler "Unable to connect to $url"
    echo "Response code: $response_code, exiting"
    exit 1
  fi

}

download_buildplane_file() {
  local url=$1
  local filename=$2

  node_status_handler "Attempting to download $url"
  if ! curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" "$url" $CURL_OPTS --output "$filename"; then
    node_status_handler "Failed to download $url"
    exit 1
  fi

  node_status_handler "Downloaded $url"
}

update_build_node_status() {
  node_status_handler "Node init script ran successfully"
  init_time=$(date -u +"%FT%TZ")
  api_response_code=$(curl -s $CURL_OPTS -X PUT -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" -d '{"lastInitializedAt":"'$init_time'"}' $PIPELINES_CORE_SERVICES_API_EXTERNALURL"/nodes/"$NODE_ID -o -l -i -w "%{http_code}")
  
  node_status_handler "node status $api_response_code"
  
  if [ "$api_response_code" != "200" ]; then
    node_status_handler "Node status failed"
    echo "Response code: $api_response_code, exiting"
    exit 1
  fi
}


