#!/bin/bash -e

if [ -z "$JFROG_DIR" ]; then
  readonly JFROG_DIR="/var/opt/jfrog/pipelines"
fi
readonly REQKICK_DIR="$JFROG_DIR/reqKick"
readonly EXECTEMPLATES_DIR="$REQKICK_DIR/node_modules/@jfrog-pipelines/core/execTemplates"
readonly EXTENSIONS_DIR="$JFROG_DIR/extensions"
readonly REQEXEC_DIR="$JFROG_DIR/reqExec"
readonly REPORTS_DIR="$JFROG_DIR/reports"
readonly NODEINIT_DIR="$JFROG_DIR/nodeInit"
readonly REQKICK_CONFIG_DIR="$JFROG_DIR/var/etc/reqKick"
readonly REQKICK_SERVICE_NAME="pipelines-reqKick"
readonly CUSTOM_CERTS_DIR="$JFROG_DIR/var/etc/security/keys/trusted"
readonly CUSTOM_CERTS_FILE_LOC="/etc/ssl/certs/ca-bundle.crt"

export BUILDPLANE_RPM_DOWNLOAD_URL="<%= buildPlaneArtifactDownloadUrl %>"
export NODE_OPERATING_SYSTEM="<%= operatingSystem %>"
export NODE_ARCHITECTURE="<%= architecture %>"
export RUN_MODE="<%= runMode %>"
export NODE_ID="<%= nodeId %>"
export PROJECT_ID="<%= projectId %>"
export BUILD_PLANE_VERSION="<%= buildPlaneVersion %>"
export PIPELINES_CORE_SERVICES_API_EXTERNALURL="<%= apiUrl %>"
export PIPELINES_SHARED_ARTIFACTORY_BASEURLUI="<%= baseUrlUI %>"
export CONFIGURE_NODE=<%= configureNode %>
export ENABLE_SWAP=<%= isSwapEnabled %>
export NO_VERIFY_SSL=<%= noVerifySsl %>
export PIPELINES_CORE_PROXY_HTTPPROXY="<%= httpProxy %>"
export PIPELINES_CORE_PROXY_HTTPSPROXY="<%= httpsProxy %>"
export PIPELINES_CORE_PROXY_NOPROXY="<%= noProxy %>"
export BOOT_BUILD_AGENT=true
export INSECURE_DOCKER_REGISTRIES='<%= insecureDockerRegistries %>'
export PIPELINES_NODE_API_TOKEN='<%= token %>'
export NODE_POLLER_INTERVAL_MS=<%= nodePollerIntervalMS %>
export CUSTOM_CERTS_DATA=<%= customCertsData %>
export CUSTOM_CERTS_ENABLED=<%= customCertsEnabled %>

if ! command -v curl; then
  yum -y check-update
  yum install -y curl
fi

CURL_OPTS=""
if [ "$CUSTOM_CERTS_ENABLED" == true ]; then
  mkdir -p $CUSTOM_CERTS_DIR
  echo -e $CUSTOM_CERTS_DATA > $CUSTOM_CERTS_DIR/ca.crt
  cp $CUSTOM_CERTS_DIR/ca.crt /usr/share/pki/ca-trust-source/anchors/
  update-ca-trust extract
elif [ "$NO_VERIFY_SSL" == true ]; then
  CURL_OPTS="--insecure"
fi

response_code=$(curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -I $BUILDPLANE_RPM_DOWNLOAD_URL $CURL_OPTS -o /dev/null -w "%{http_code}" -s -L)
if [ "$response_code" != "200" ]; then
  echo "Unable to connect to $BUILDPLANE_RPM_DOWNLOAD_URL"
  echo "Response code: $response_code, exiting"
  exit 1
fi

curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" $BUILDPLANE_RPM_DOWNLOAD_URL $CURL_OPTS --output buildPlane.rpm

rpm -i --prefix=$JFROG_DIR --force buildPlane.rpm

source $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh

init_time=$(date -u +"%FT%TZ")
api_response_code=$(curl -s $CURL_OPTS -X PUT -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" -d '{"lastInitializedAt":"'$init_time'"}' $PIPELINES_CORE_SERVICES_API_EXTERNALURL"/nodes/"$NODE_ID -o -l -i -w "%{http_code}")
