#!/bin/bash -e

export ROOT_USER_INIT=<%= rootUserInit %>
if [ -z "$JFROG_DIR" ]; then
  if [ "$ROOT_USER_INIT" == true ]; then
    export JFROG_DIR="/var/opt/jfrog/pipelines"
  else
    export USERNAME="pipelinesRootless"
    export GROUPNAME="pipelinesRootless"
    export JFROG_DIR="/home/$USERNAME/.jfrog/pipelines"
  fi
fi
export REQKICK_DIR="$JFROG_DIR/reqKick"
export EXECTEMPLATES_DIR="$REQKICK_DIR/node_modules/@jfrog-pipelines/core/execTemplates"
export EXTENSIONS_DIR="$JFROG_DIR/extensions"
export REQEXEC_DIR="$JFROG_DIR/reqExec"
export REPORTS_DIR="$JFROG_DIR/reports"
export NODEINIT_DIR="$JFROG_DIR/nodeInit"
export REQKICK_CONFIG_DIR="$JFROG_DIR/var/etc/reqKick"
export REQKICK_SERVICE_NAME="pipelines-reqKick"
export CUSTOM_CERTS_DIR="$JFROG_DIR/var/etc/security/keys/trusted"
export CUSTOM_CERTS_FILE_LOC="/etc/ssl/certs/ca-certificates.crt"

export BUILDPLANE_DEB_DOWNLOAD_URL="<%= buildPlaneArtifactDownloadUrl %>"
export NODE_OPERATING_SYSTEM="<%= operatingSystem %>"
export NODE_ARCHITECTURE="<%= architecture %>"
export RUN_MODE="<%= runMode %>"
export NODE_ID="<%= nodeId %>"
export PROJECT_ID="<%= projectId %>"
export BUILD_PLANE_VERSION="<%= buildPlaneVersion %>"
export PIPELINES_CORE_SERVICES_API_EXTERNALURL="<%= apiUrl %>"
export PIPELINES_SHARED_ARTIFACTORY_BASEURLUI="<%= baseUrlUI %>"
export CONFIGURE_NODE=<%= configureNode %>
export ENABLE_SWAP=<%= isSwapEnabled %>
export NO_VERIFY_SSL=<%= noVerifySsl %>
export PIPELINES_CORE_PROXY_HTTPPROXY="<%= httpProxy %>"
export PIPELINES_CORE_PROXY_HTTPSPROXY="<%= httpsProxy %>"
export PIPELINES_CORE_PROXY_NOPROXY="<%= noProxy %>"
export BOOT_BUILD_AGENT=true
export INSECURE_DOCKER_REGISTRIES='<%= insecureDockerRegistries %>'
export PIPELINES_NODE_API_TOKEN='<%= token %>'
export NODE_POLLER_INTERVAL_MS=<%= nodePollerIntervalMS %>
export CUSTOM_CERTS_DATA=<%= customCertsData %>
export CUSTOM_CERTS_ENABLED=<%= customCertsEnabled %>

if ! command -v curl; then
  if [ "$ROOT_USER_INIT" == true ]; then
    apt-get update
    apt-get install -y curl
  else
    echo "Error: Could not find curl in the system."
    echo "Please install all the pre-requisites before running the init script."
    exit 1
  fi
fi

CURL_OPTS=""
if [ "$CUSTOM_CERTS_ENABLED" == true ]; then
  mkdir -p $CUSTOM_CERTS_DIR
  echo -e $CUSTOM_CERTS_DATA > $CUSTOM_CERTS_DIR/ca.crt
  cp $CUSTOM_CERTS_DIR/ca.crt /usr/local/share/ca-certificates/
  update-ca-certificates
elif [ "$NO_VERIFY_SSL" == true ]; then
  CURL_OPTS="--insecure"
fi

response_code=$(curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -I $BUILDPLANE_DEB_DOWNLOAD_URL $CURL_OPTS -o /dev/null -w "%{http_code}" -s -L)
if [ "$response_code" != "200" ]; then
  echo "Unable to connect to $BUILDPLANE_DEB_DOWNLOAD_URL"
  echo "Response code: $response_code, exiting"
  exit 1
fi

curl -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" $BUILDPLANE_DEB_DOWNLOAD_URL $CURL_OPTS --output buildPlane.deb

if [ "$ROOT_USER_INIT" == true ]; then
  if [ "$JFROG_DIR" == "/var/opt/jfrog/pipelines" ]; then
    dpkg -i buildPlane.deb
  else
    mkdir -p $JFROG_DIR
    dpkg -i --instdir=$JFROG_DIR buildPlane.deb
    mv $JFROG_DIR/var/opt/jfrog/pipelines/* $JFROG_DIR
  fi
  source $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh
else
  mkdir -p /home/$USERNAME/.jfrog/pipelines
  mkdir -p /home/$USERNAME/.local/share/docker
  mkdir -p /home/$USERNAME/.config/systemd/user
  mkdir -p /home/$USERNAME/.jfrog/pipelines/var/etc/reqKick
  dpkg -x buildPlane.deb /home/$USERNAME/.jfrog/pipelines

  if [ ! -d /home/$USERNAME/.jfrog/pipelines/extensions ]; then
    mv -f /home/$USERNAME/.jfrog/pipelines/var/opt/jfrog/pipelines/* /home/$USERNAME/.jfrog/pipelines
  fi

  export XDG_RUNTIME_DIR=/run/user/1066
  export HOME=/home/$USERNAME
  export PATH=/home/$USERNAME/bin:$PATH
  export DOCKER_HOST=unix://$XDG_RUNTIME_DIR/docker.sock
  $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.sh $ROOT_USER_INIT /home/$USERNAME
fi

init_time=$(date -u +"%FT%TZ")
api_response_code=$(curl -s $CURL_OPTS -X PUT -H "Authorization: Bearer $PIPELINES_NODE_API_TOKEN" -H "Content-Type: application/json" -d '{"lastInitializedAt":"'$init_time'"}' $PIPELINES_CORE_SERVICES_API_EXTERNALURL"/nodes/"$NODE_ID -o -l -i -w "%{http_code}")
