"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeConsoleQueryApi = void 0;
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const sortOrderForSequelize_1 = require("../../shared/sortOrderForSequelize");
const NodeConsoleService_1 = require("./NodeConsoleService");
const NodeConsoleDao_1 = require("./NodeConsoleDao");
class NodeConsoleQueryApi {
    constructor() {
        this.nodeConsoleService = new NodeConsoleService_1.NodeConsoleService();
        this.nodeConsoleDao = new NodeConsoleDao_1.NodeConsoleDao();
    }
    async create(nodeId, messages) {
        const nodeConsoles = Array.isArray(messages)
            ? messages.map((message) => this.nodeConsoleService.createNodeConsole(message, nodeId))
            : this.nodeConsoleService.createNodeConsole(messages, nodeId);
        await this.nodeConsoleService.insertNodeConsole(nodeConsoles);
    }
    async getAll(nodeId, additionalGetOptions) {
        const queryObject = {
            sortBy: additionalGetOptions.sort ?? 'timestamp',
            sortOrder: (0, sortOrderForSequelize_1.getSortOrderForSequelize)(additionalGetOptions.order),
            limit: additionalGetOptions.limit
        };
        const queryBuilder = new data_access_layer_1.SequelizeQueryBuilder(queryObject)
            .where('nodeId', nodeId)
            .limit()
            .offset(additionalGetOptions.skip)
            .sort()
            .build();
        const result = await this.nodeConsoleDao.findAll(queryBuilder);
        const requiredResponse = result.map((item) => {
            return {
                ...item.toJSON(),
                createdAt: item.createdAt.toDateString()
            };
        });
        return requiredResponse;
    }
}
exports.NodeConsoleQueryApi = NodeConsoleQueryApi;
//# sourceMappingURL=NodeConsoleApi.js.map