"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeConsoleService = void 0;
const utility_1 = require("@jfrog-pipelines/utility");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const NodeConsoleDao_1 = require("./NodeConsoleDao");
class NodeConsoleService {
    constructor() {
        this.nodeConsoleDao = new NodeConsoleDao_1.NodeConsoleDao();
        this.startTimeInMs = Date.now() * 1000;
        const processStartTime = process.hrtime();
        this.processStartTimeInMicroSec = processStartTime[0] * 1e6 + processStartTime[1] / 1e3;
    }
    async push(message, nodeId) {
        const newNodeConsole = this.createNodeConsole(message, nodeId);
        await this.insertNodeConsole(newNodeConsole);
    }
    createNodeConsole(message, nodeId) {
        const consoleId = (0, utility_1.uuidv5)(new Date().toISOString(), utility_1.uuidv5.URL);
        return {
            nodeId: nodeId,
            consoleId: consoleId,
            parentConsoleId: 'root',
            type: 'msg',
            timestamp: this.getTimeStamp(),
            message: message,
            isShown: true
        };
    }
    async insertNodeConsole(nodeConsole) {
        await (Array.isArray(nodeConsole)
            ? this.nodeConsoleDao.createBulk(nodeConsole)
            : this.nodeConsoleDao.create(nodeConsole));
    }
    async deleteByNodeId(nodeId) {
        const query = new data_access_layer_1.SequelizeQueryBuilder({}).where('nodeId', nodeId).build();
        await this.nodeConsoleDao.delete(query);
    }
    getTimeStamp() {
        const currentProcessTime = process.hrtime();
        return Math.round(this.startTimeInMs + (currentProcessTime[0] * 1e6 + currentProcessTime[1] / 1e3) - this.processStartTimeInMicroSec);
    }
}
exports.NodeConsoleService = NodeConsoleService;
//# sourceMappingURL=NodeConsoleService.js.map