"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeStatsCleanupHandler = void 0;
const node_util_1 = require("node:util");
const microservice_1 = require("@jfrog-pipelines/microservice");
const configuration_1 = require("@jfrog-pipelines/configuration");
const LockService_1 = require("../lock/LockService");
const NodeStatsService_1 = require("./NodeStatsService");
const CUT_OFF_TIME_3_DAYS_IN_MS = 259200000;
const LOCK_TIMEOUT_10_MIN_IN_MS = 600000;
class NodeStatsCleanupHandler {
    constructor() {
        this.nodeStatsService = new NodeStatsService_1.NodeStatsService();
        this.properties = configuration_1.ConfigFactory.config;
    }
    async handle(payload) {
        if (!this.isNodesAllowed()) {
            return;
        }
        const reportedBeforeTime = this.getReportedBeforeTime();
        const lock = new LockService_1.LockService(microservice_1.applicationContext.get(microservice_1.SYSTEM_SERVICE_INSTANCE_INITIALIZER)?.systemServiceInstancesId);
        const lockName = `cron-NodeStatsCleanup`;
        const lockCreateParameters = {
            lockTimeoutInMs: LOCK_TIMEOUT_10_MIN_IN_MS,
            name: lockName
        };
        try {
            await lock.obtainLock(lockCreateParameters);
            await this.nodeStatsService.deleteNodeStats(reportedBeforeTime);
        }
        catch (error) {
            throw new Error((0, node_util_1.inspect)(error));
        }
        finally {
            await lock.releaseLock(lockName);
        }
    }
    isNodesAllowed() {
        if (this.properties.allowDynamicNodes || this.properties.allowCustomNodes) {
            return true;
        }
        return false;
    }
    getReportedBeforeTime() {
        const dateNow = new Date();
        const reportedBefore = new Date(dateNow.getTime() - CUT_OFF_TIME_3_DAYS_IN_MS).toISOString();
        return reportedBefore;
    }
}
exports.NodeStatsCleanupHandler = NodeStatsCleanupHandler;
//# sourceMappingURL=NodeStatsCleanupHandler.js.map