"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_crypto_1 = require("node:crypto");
const utility_1 = require("@jfrog-pipelines/utility");
const expect_1 = __importDefault(require("expect"));
const LockService_1 = require("../../lock/LockService");
const NodeStatsCleanupHandler_1 = require("../NodeStatsCleanupHandler");
const NodeStatsService_1 = require("../NodeStatsService");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { allowDynamicNodes: true, allowCustomNodes: true } }
    };
});
describe('NodeStatsHandler', () => {
    const nodeStatHandler = new NodeStatsCleanupHandler_1.NodeStatsCleanupHandler();
    it('should throw error as lock is not released yet', async () => {
        const payload = {
            actor: utility_1.Actor.nodeStats,
            operation: utility_1.Operation.delete
        };
        const lockName = `cron-${payload.operation}${payload.actor}`;
        const obtainLockSpy = jest
            .spyOn(LockService_1.LockService.prototype, 'obtainLock')
            .mockRejectedValueOnce(new Error(`Lock already exists with name ${lockName}`));
        const releaseLockSpy = jest.spyOn(LockService_1.LockService.prototype, 'releaseLock').mockResolvedValueOnce();
        await (0, expect_1.default)(nodeStatHandler.handle(payload)).rejects.toThrow(`Lock already exists with name ${lockName}`);
        (0, expect_1.default)(obtainLockSpy).toHaveBeenCalledTimes(1);
        (0, expect_1.default)(releaseLockSpy).toHaveBeenCalledTimes(1);
    });
    it('should delete nodeStats as payload is valid', async () => {
        const payload = {
            actor: utility_1.Actor.nodeStats,
            operation: utility_1.Operation.delete
        };
        const lockResponse = { id: (0, node_crypto_1.randomUUID)() };
        const obtainLockSpy = jest.spyOn(LockService_1.LockService.prototype, 'obtainLock').mockResolvedValue(lockResponse);
        const deleteNodeStatsSpy = jest.spyOn(NodeStatsService_1.NodeStatsService.prototype, 'deleteNodeStats').mockResolvedValueOnce(1);
        const releaseLockSpy = jest.spyOn(LockService_1.LockService.prototype, 'releaseLock').mockResolvedValueOnce();
        await nodeStatHandler.handle(payload);
        (0, expect_1.default)(obtainLockSpy).toHaveBeenCalledTimes(1);
        (0, expect_1.default)(deleteNodeStatsSpy).toHaveBeenCalledTimes(1);
        (0, expect_1.default)(releaseLockSpy).toHaveBeenCalledTimes(1);
    });
});
//# sourceMappingURL=NodeStatsCleanupHandler.test.js.map