"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.nodepoolRoutesV1 = void 0;
const node_util_1 = require("node:util");
const http_client_1 = require("@jfrog-pipelines/http-client");
const logger_1 = require("@jfrog-pipelines/logger");
const NodeStatsApi_1 = require("../../modules/nodeStats/NodeStatsApi");
const NodeConsoleApi_1 = require("../../modules/nodeConsole/NodeConsoleApi");
const NodeApi_1 = require("../../modules/node/NodeApi");
const NodeStatsSchema_1 = require("./schema/NodeStatsSchema");
const NodeConsoleSchema_1 = require("./schema/NodeConsoleSchema");
const NodeSchema_1 = require("./schema/NodeSchema");
const logger = logger_1.LoggerFactory.getLogger('nodepoolRoutesV1');
const nodepoolRoutesV1 = () => {
    return (httpServer) => {
        httpServer.post('/nodes/:nodeId/stats', { schema: NodeStatsSchema_1.NodeStatsPost }, async (request, response) => {
            try {
                const nodeStatsApi = new NodeStatsApi_1.NodeStatsQuery();
                const { nodeId } = request.params;
                const body = request.body;
                await nodeStatsApi.create(nodeId, body);
            }
            catch (error) {
                const receivedError = error;
                logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
                return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                    message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
                });
            }
        });
        httpServer.get('/nodes/:nodeId/stats', { schema: NodeStatsSchema_1.NodeStatsGet }, async (request, response) => {
            try {
                const nodeStatsApi = new NodeStatsApi_1.NodeStatsQuery();
                const { nodeId } = request.params;
                const query = request.query;
                return await nodeStatsApi.getAll(nodeId, query);
            }
            catch (error) {
                const receivedError = error;
                logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
                return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                    message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
                });
            }
        });
        httpServer.post('/nodes/:nodeId/console', { schema: NodeConsoleSchema_1.NodeConsolePost }, async (request, response) => {
            try {
                const nodeConsoleQueryApi = new NodeConsoleApi_1.NodeConsoleQueryApi();
                const { nodeId } = request.params;
                const body = request.body;
                await nodeConsoleQueryApi.create(nodeId, body.message);
            }
            catch (error) {
                const receivedError = error;
                logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
                return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                    message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
                });
            }
        });
        httpServer.get('/nodes/:nodeId/console', { schema: NodeConsoleSchema_1.NodeConsoleGet }, async (request, response) => {
            try {
                const nodeConsoleQueryApi = new NodeConsoleApi_1.NodeConsoleQueryApi();
                const { nodeId } = request.params;
                const query = request.query;
                return await nodeConsoleQueryApi.getAll(nodeId, query);
            }
            catch (error) {
                const receivedError = error;
                logger.warn(`Failed posting nodeStats due to error: ${(0, node_util_1.inspect)(receivedError.ormError?.name)}: ${receivedError.message}`);
                return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.NOT_FOUND).send({
                    message: `${receivedError.ormError?.name ?? ''} ${receivedError.message}`
                });
            }
        });
        httpServer.get('/nodes/:nodeId/init_script', { schema: NodeSchema_1.NodeInitScriptGet }, async (request, response) => {
            try {
                const nodeQueryApi = new NodeApi_1.NodeQueryApi();
                const { nodeId } = request.params;
                const query = request.query;
                const result = await nodeQueryApi.getNodeInitScript(nodeId, query.nodePoolIds);
                return await response
                    .header('Content-disposition', `attachment; filename=${result.scriptName}`)
                    .type('application/x-sh')
                    .send(result.scriptData);
            }
            catch (error) {
                const receivedError = error;
                return response.code(receivedError.statusCode ?? http_client_1.HttpStatus.INTERNAL_SERVER_ERROR).send({
                    message: `${receivedError.name ?? ''} ${receivedError.message}`
                });
            }
        });
    };
};
exports.nodepoolRoutesV1 = nodepoolRoutesV1;
//# sourceMappingURL=index.js.map